@@ -36,18 +36,29 @@ extern XC(func_info_type)
 int XC(functional_get_number)(const char *name)
 {
   int ii;
+  int key=-1;
+  const char *p;
+
+  /* Does name begin with xc_? */
+  if(strncasecmp(name,"XC_",3) == 0) {
+    p=name+3;
+  } else {
+    p=name;
+  }
 
   for(ii=0;;ii++){
     if(XC(functional_keys)[ii].number == -1)
-      return -1;
-    if(strncasecmp(XC(functional_keys)[ii].name, name, 256) == 0) 
-      return XC(functional_keys)[ii].number;
+      break;
+    if(strcasecmp(XC(functional_keys)[ii].name, p) == 0) 
+      key=XC(functional_keys)[ii].number;
   }
+  
+  return key;
 }
 
 
 /*------------------------------------------------------*/
-char *XC(functional_get_name)(int number)
+char *XC(functional_get_name)(const int number)
 {
   int ii;
 
@@ -114,6 +125,14 @@ int XC(family_from_id)(int id, int *family, int *number)
   return XC_FAMILY_UNKNOWN;
 }
 
+/*------------------------------------------------------*/
+XC(func_type) *XC(func_alloc)()
+{
+  XC(func_type) *func;
+
+  func = (XC(func_type) *) malloc (sizeof (XC(func_type)));
+  return func;
+}
 
 /*------------------------------------------------------*/
 int XC(func_init)(XC(func_type) *p, int functional, int nspin)
@@ -176,6 +195,19 @@ void XC(func_end)(XC(func_type) *p)
   p->info = NULL;  
 }
 
+/*------------------------------------------------------*/
+void  XC(func_free)(XC(func_type) *p)
+{
+  free(p);
+}
+
+/*------------------------------------------------------*/
+const XC(func_info_type) *XC(func_get_info)(const XC(func_type) *p)
+{
+  return p->info;
+}
+
+
 /* returns the mixing coefficient for the hybrid GGAs */
 FLOAT XC(hyb_exx_coef)(const XC(func_type) *p)
 {
@@ -193,3 +225,12 @@ void XC(hyb_cam_coef)(const XC(func_type) *p, FLOAT *omega, FLOAT *alpha, FLOAT
   *alpha = p->cam_alpha;
   *beta  = p->cam_beta;
 }
+
+/* returns the NLC parameters */
+void XC(nlc_coef)(const XC(func_type) *p, FLOAT *nlc_b, FLOAT *nlc_C)
+{
+  assert(p!=NULL);
+
+  *nlc_b = p->nlc_b;
+  *nlc_C = p->nlc_C;
+}
