@@ -113,8 +113,7 @@ const XC(func_info_type) XC(func_info_gga_c_am05) = {
   XC_CORRELATION,
   "Armiento & Mattsson 05",
   XC_FAMILY_GGA,
-  "R Armiento and AE Mattsson, Phys. Rev. B 72, 085108 (2005)\n"
-  "AE Mattsson, R Armiento, J Paier, G Kresse, JM Wills, and TR Mattsson, J. Chem. Phys. 128, 084714 (2008).",
+  {&xc_ref_Armiento2005_085108, &xc_ref_Mattsson2008_084714, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-27, 1e-32, 0.0, 1e-32,
   gga_c_am05_init,
