@@ -86,7 +86,7 @@ const XC(func_info_type) XC(func_info_gga_c_wl) = {
   XC_CORRELATION,
   "Wilson & Levy",
   XC_FAMILY_GGA,
-  "LC Wilson and M Levy, Phys. Rev. B 41, 12930 (1990)",
+  {&xc_ref_Wilson1990_12930, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   NULL, NULL, NULL,
