@@ -162,7 +162,7 @@ const XC(func_info_type) XC(func_info_gga_k_dk) = {
   XC_KINETIC,
   "DePristo and Kress",
   XC_FAMILY_GGA,
-  "AE DePristo and JD Kress, Phys. Rev. A 35, 438-441 (1987)",
+  {&xc_ref_DePristo1987_438, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_k_dk_init,
@@ -176,7 +176,7 @@ const XC(func_info_type) XC(func_info_gga_k_perdew) = {
   XC_KINETIC,
   "Perdew",
   XC_FAMILY_GGA,
-  "JP Perdew, Phys. Lett. A 165, 79 (1992)",
+  {&xc_ref_Perdew1992_79, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_k_dk_init,
@@ -190,7 +190,7 @@ const XC(func_info_type) XC(func_info_gga_k_vsk) = {
   XC_KINETIC,
   "Vitos, Skriver, and Kollar",
   XC_FAMILY_GGA,
-  "L Vitos, HL Skriver, and J. Kollár, Phys. Rev. B 57, 12611-12615 (1998)",
+  {&xc_ref_Vitos1998_12611, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_k_dk_init,
@@ -204,7 +204,7 @@ const XC(func_info_type) XC(func_info_gga_k_vjks) = {
   XC_KINETIC,
   "Vitos, Johansson, Kollar, and Skriver",
   XC_FAMILY_GGA,
-  "L Vitos, B Johansson, J. Kollár, and HL Skriver, Phys. Rev. A 61, 052511 (2000)",
+  {&xc_ref_Vitos2000_052511, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_k_dk_init,
@@ -218,7 +218,7 @@ const XC(func_info_type) XC(func_info_gga_k_ernzerhof) = {
   XC_KINETIC,
   "Ernzerhof",
   XC_FAMILY_GGA,
-  "M Ernzerhof, J. Mol. Struct.:THEOCHEM 501-502, 59 (2000)",
+  {&xc_ref_Ernzerhof2000_59, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_k_dk_init,
