@@ -149,7 +149,7 @@ const XC(func_info_type) XC(func_info_gga_x_b88) = {
   XC_EXCHANGE,
   "Becke 88",
   XC_FAMILY_GGA,
-  "AD Becke, Phys. Rev. A 38, 3098 (1988)",
+  {&xc_ref_Becke1988_3098, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_b88_init, 
@@ -164,7 +164,7 @@ const XC(func_info_type) XC(func_info_gga_x_optb88_vdw) = {
   XC_EXCHANGE,
   "opt-Becke 88 for vdW",
   XC_FAMILY_GGA,
-  "J Klimes, DR Bowler, and A Michaelides, J. Phys.: Condens. Matter 22, 022201 (2010)",
+  {&xc_ref_Klimes2010_022201, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_b88_init,
@@ -179,7 +179,7 @@ const XC(func_info_type) XC(func_info_gga_x_mb88) = {
   XC_EXCHANGE,
   "Modified Becke 88 for proton transfer",
   XC_FAMILY_GGA,
-  "V Tognetti and C Adamo, J. Phys. Chem. A 113, 14415-14419 (2009)",
+  {&xc_ref_Tognetti2009_14415, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_b88_init, 
@@ -195,9 +195,9 @@ const XC(func_info_type) XC(func_info_gga_x_mb88) = {
 const XC(func_info_type) XC(func_info_gga_k_llp) = {
   XC_GGA_K_LLP,
   XC_KINETIC,
-  "Becke 88",
+  "Lee, Lee & Parr",
   XC_FAMILY_GGA,
-  "H Lee, C Lee, and RG Parr, Phys. Rev. A 44, 768 (1991)",
+  {&xc_ref_Lee1991_768, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_b88_init,
@@ -212,7 +212,7 @@ const XC(func_info_type) XC(func_info_gga_k_fr_b88) = {
   XC_KINETIC,
   "Fuentealba & Reyes (B88 version)",
   XC_FAMILY_GGA,
-  "P Fuentealba and O Reyes, Chem. Phys. Lett. 232, 31-34 (1995)",
+  {&xc_ref_Fuentealba1995_31, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_b88_init,
@@ -227,7 +227,7 @@ const XC(func_info_type) XC(func_info_gga_k_thakkar) = {
   XC_KINETIC,
   "Thakkar 1992",
   XC_FAMILY_GGA,
-  "AJ Thakkar, Phys. Rev. A 46, 6920-6924 (1992)",
+  {&xc_ref_Thakkar1992_6920, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_b88_init,
