@@ -74,7 +74,7 @@ const XC(func_info_type) XC(func_info_gga_x_dk87_r1) = {
   XC_EXCHANGE,
   "dePristo & Kress 87 version R1",
   XC_FAMILY_GGA,
-  "AE DePristo and JD Kress, J. Chem. Phys. 86, 1425 (1987)",
+  {&xc_ref_DePristo1987_1425, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-24, 1e-24, 0.0, 1e-32,
   NULL, NULL, NULL,
@@ -87,7 +87,7 @@ const XC(func_info_type) XC(func_info_gga_x_dk87_r2) = {
   XC_EXCHANGE,
   "dePristo & Kress 87 version R2",
   XC_FAMILY_GGA,
-  "AE DePristo and JD Kress, J. Chem. Phys. 86, 1425 (1987)",
+  {&xc_ref_DePristo1987_1425, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   NULL, NULL, NULL,
