@@ -99,7 +99,7 @@ const XC(func_info_type) XC(func_info_gga_x_kt1) = {
   XC_EXCHANGE,
   "Keal and Tozer, version 1",
   XC_FAMILY_GGA,
-  "TW Keal and DJ Tozer, J. Chem. Phys. 119, 3015 (2003)",
+  {&xc_ref_Keal2003_3015, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_kt_init, 
@@ -114,7 +114,7 @@ const XC(func_info_type) XC(func_info_gga_xc_kt2) = {
   XC_EXCHANGE_CORRELATION,
   "Keal and Tozer, version 2",
   XC_FAMILY_GGA,
-  "TW Keal and DJ Tozer, J. Chem. Phys. 119, 3015 (2003)",
+  {&xc_ref_Keal2003_3015, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_xc_kt2_init, 
