@@ -106,7 +106,7 @@ void
 XC(gga_lb_modified)(const XC(func_type) *func, int np, const FLOAT *rho, const FLOAT *sigma, FLOAT r, FLOAT *vrho)
 {
   int ip, is, is2;
-  FLOAT ds, gdm, x, sfact, sfact2;
+  FLOAT ds, gdm, x, sfact;
 
   XC(gga_x_lb_params) *params;
 
@@ -118,7 +118,6 @@ XC(gga_lb_modified)(const XC(func_type) *func, int np, const FLOAT *rho, const F
   XC(lda_vxc)(func->func_aux[0], np, rho, vrho);
 
   sfact = (func->nspin == XC_POLARIZED) ? 1.0 : 2.0;
-  sfact2 = sfact*sfact;
 
   for(ip=0; ip<np; ip++){
     for(is=0; is<func->nspin; is++){
@@ -145,7 +144,7 @@ XC(gga_lb_modified)(const XC(func_type) *func, int np, const FLOAT *rho, const F
 	vrho[is] += f * CBRT(ds);
 	
       }else if(r > 0.0){
-	/* the aymptotic expansion of LB94 */
+	/* the asymptotic expansion of LB94 */
 	x = r + (3.0/params->aa)*
 	  LOG(2.0*params->gamm * params->aa * 1.0 / CBRT(params->qtot));
 	
@@ -175,12 +174,12 @@ gga_x_lb(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma,
 }
 
 
-XC(func_info_type) XC(func_info_gga_x_lb) = {
+const XC(func_info_type) XC(func_info_gga_x_lb) = {
   XC_GGA_X_LB,
   XC_EXCHANGE,
   "van Leeuwen & Baerends",
   XC_FAMILY_GGA,
-  "R van Leeuwen and EJ Baerends, Phys. Rev. A. 49, 2421 (1994)",
+  {&xc_ref_vanLeeuwen1994_2421, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_lb_init,
@@ -190,13 +189,12 @@ XC(func_info_type) XC(func_info_gga_x_lb) = {
   NULL
 };
 
-XC(func_info_type) XC(func_info_gga_x_lbm) = {
+const XC(func_info_type) XC(func_info_gga_x_lbm) = {
   XC_GGA_X_LBM,
   XC_EXCHANGE,
   "van Leeuwen & Baerends modified",
   XC_FAMILY_GGA,
-  "PRT Schipper, OV Gritsenko, SJA van Gisbergen, and EJ Baerends, J. Chem. Phys. 112, 1344 (2000)\n"
-  "R van Leeuwen and EJ Baerends, Phys. Rev. A. 49, 2421 (1994)",
+  {&xc_ref_Schipper2000_1344, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_lb_init,
