@@ -31,6 +31,13 @@
 #define XC_GGA_X_APBE         184 /* mu fixed from the semiclassical neutral atom   */
 #define XC_GGA_X_PBEINT        60 /* PBE for hybrid interfaces                      */
 #define XC_GGA_X_PBE_TCA       59 /* PBE revised by Tognetti et al                  */
+#define XC_GGA_X_PBE_MOL       49 /* Del Campo, Gazquez, Trickey and Vela (PBE-like) */
+#define XC_GGA_X_LAMBDA_LO_N   45 /* lambda_LO(N) version of PBE                    */
+#define XC_GGA_X_LAMBDA_CH_N   44 /* lambda_CH(N) version of PBE                    */
+#define XC_GGA_X_LAMBDA_OC2_N  40 /* lambda_OC2(N) version of PBE                   */
+#define XC_GGA_X_BGCP          38 /* Burke, Cancio, Gould, and Pittalis             */
+#define XC_GGA_X_PBEFE        265 /* PBE for formation energies                     */
+
 #define XC_GGA_K_APBE         185 /* mu fixed from the semiclassical neutral atom   */
 #define XC_GGA_K_TW1          187 /* Tran and Wesolowski set 1 (Table II)           */
 #define XC_GGA_K_TW2          188 /* Tran and Wesolowski set 2 (Table II)           */
@@ -39,42 +46,50 @@
 #define XC_GGA_K_REVAPBE       55 /* revised APBE                                   */
 #define XC_GGA_K_APBEINT       54 /* interpolated version of APBE                   */
 #define XC_GGA_K_REVAPBEINT    53 /* interpolated version of REVAPBE                */
-#define XC_GGA_X_PBE_MOL       49 /* Del Campo, Gazquez, Trickey and Vela (PBE-like) */
+
 
 typedef struct{
   FLOAT kappa, mu;
 
   /* parameters only used for PBEint and similar functionals */
   FLOAT alpha, muPBE, muGE;
+
+  /* parameter used in the Odashima & Capelle versions */
+  FLOAT lambda;
 } gga_x_pbe_params;
 
 
 static void 
 gga_x_pbe_init(XC(func_type) *p)
 {
-  static const FLOAT kappa[19] = {
-    0.8040,  /* original PBE */
-    1.245,   /* PBE R       */
-    0.8040,  /* PBE sol     */
-    0.91954, /* xPBE        */
-    0.8040,  /* PBE_JSJR    */
-    1.0,     /* PBEK1_VDW   */
-    0.8040,  /* RGE2        */
-    0.8040,  /* APBE (X)    */
-    0.8040,  /* APBE (K)    */
-    0.8209,  /* TW1         */
-    0.6774,  /* TW2         */
-    0.8438,  /* TW3         */
-    0.8589,  /* TW4         */
-    0.8040,  /* PBEint      */
-    1.227,   /* PBE TCA     */
-    1.245,   /* revAPBE (K) */
-    0.8040,  /* APBEINT (K) */
-    1.245,   /* revAPBEINT (K) */
-    0.8040   /* PBEmol    */
+  static const FLOAT kappa[] = {
+    0.8040,                 /* original PBE */
+    1.245,                  /* PBE R       */
+    0.8040,                 /* PBE sol     */
+    0.91954,                /* xPBE        */
+    0.8040,                 /* PBE_JSJR    */
+    1.0,                    /* PBEK1_VDW   */
+    0.8040,                 /* RGE2        */
+    0.8040,                 /* APBE (X)    */
+    0.8040,                 /* APBE (K)    */
+    0.8209,                 /* TW1         */
+    0.6774,                 /* TW2         */
+    0.8438,                 /* TW3         */
+    0.8589,                 /* TW4         */
+    0.8040,                 /* PBEint      */
+    1.227,                  /* PBE TCA     */
+    1.245,                  /* revAPBE (K) */
+    0.8040,                 /* APBEINT (K) */
+    1.245,                  /* revAPBEINT (K) */
+    0.8040,                 /* PBEmol    */
+    2.273/M_CBRT2 - 1.0,    /* LAMBDA_LO(N)  */
+    2.215/M_CBRT2 - 1.0,    /* LAMBDA_CH(N)  */
+    2.00 /M_CBRT2 - 1.0,    /* LAMBDA_OC2(N) */
+    0.8040,                 /* BGCP (X)    */
+    0.437,                  /* PBEfe       */
   };
 
-  static const FLOAT mu[19] = {
+  static const FLOAT mu[] = {
     0.2195149727645171,     /* PBE: mu = beta*pi^2/3, beta = 0.06672455060314922 */
     0.2195149727645171,     /* PBE rev: as PBE */
     10.0/81.0,              /* PBE sol */
@@ -93,7 +108,12 @@ gga_x_pbe_init(XC(func_type) *p)
     0.23889,                /* revAPBE (K)  */
     0.0,                    /* APBEINT (K) (to be set later) */
     0.0,                    /* REVAPBEINT (K) (to be set later) */
-    0.27583                 /* PBEmol    */
+    0.27583,                /* PBEmol        */
+    0.2195149727645171,     /* LAMBDA_LO(N)  */
+    0.2195149727645171,     /* LAMBDA_CH(N)  */
+    0.2195149727645171,     /* LAMBDA_OC2(N) */
+    0.249,                  /* BGCP (X)    */
+    0.346,                  /* PBEfe       */
   };
 
   gga_x_pbe_params *params;
@@ -102,9 +122,11 @@ gga_x_pbe_init(XC(func_type) *p)
   p->params = malloc(sizeof(gga_x_pbe_params));
   params = (gga_x_pbe_params *) (p->params);
  
-  params->alpha = 0.0;
-  params->muPBE = 0.0;
-  params->muGE  = 0.0;
+  /* initialize structure */
+  params->alpha  = 0.0;
+  params->muPBE  = 0.0;
+  params->muGE   = 0.0;
+  params->lambda = 0.0;
 
   switch(p->info->number){
   case XC_GGA_X_PBE:        p->func = 0;  break;
@@ -144,6 +166,25 @@ gga_x_pbe_init(XC(func_type) *p)
     break;
   }
   case XC_GGA_X_PBE_MOL:    p->func = 18; break;
+
+  case XC_GGA_X_LAMBDA_LO_N: {
+    p->func = 19;
+    params->lambda = 2.273;
+    break;
+  }
+  case XC_GGA_X_LAMBDA_CH_N: {
+    p->func = 20;
+    params->lambda = 2.215;
+    break;
+  }
+  case XC_GGA_X_LAMBDA_OC2_N: {
+    p->func = 21;
+    params->lambda = 2.00;
+    break;
+  }
+  case XC_GGA_X_BGCP:    p->func = 22; break;
+  case XC_GGA_X_PBEFE:   p->func = 23; break;
+
   default:{
     fprintf(stderr, "Internal error in gga_x_pbe\n");
     exit(1);
@@ -166,6 +207,22 @@ XC(gga_x_pbe_set_params)(XC(func_type) *p, FLOAT kappa, FLOAT mu)
 }
 
 
+void 
+XC(gga_x_lambda_set_params)(XC(func_type) *p, FLOAT N)
+{
+  const FLOAT lambda_1 = 1.48;
+
+  gga_x_pbe_params *params;
+  FLOAT lambda;
+
+  assert(p != NULL && p->params != NULL);
+  params = (gga_x_pbe_params *) (p->params);
+
+  lambda = (1.0 - 1.0/N)*params->lambda + lambda_1/N;
+  params->kappa = lambda/M_CBRT2 - 1.0;
+}
+
+
 void XC(gga_x_pbe_enhance) 
   (const XC(func_type) *p, int order, FLOAT x, 
    FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
@@ -246,8 +303,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbe) = {
   XC_EXCHANGE,
   "Perdew, Burke & Ernzerhof",
   XC_FAMILY_GGA,
-  "JP Perdew, K Burke, and M Ernzerhof, Phys. Rev. Lett. 77, 3865 (1996)\n"
-  "JP Perdew, K Burke, and M Ernzerhof, Phys. Rev. Lett. 78, 1396(E) (1997)",
+  {&xc_ref_Perdew1996_3865, &xc_ref_Perdew1996_3865_err, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
@@ -261,7 +317,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbe_r) = {
   XC_EXCHANGE,
   "Revised PBE from Zhang & Yang",
   XC_FAMILY_GGA,
-  "Y Zhang and W Yang, Phys. Rev. Lett 80, 890 (1998)",
+  {&xc_ref_Zhang1998_890, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
@@ -275,7 +331,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbe_sol) = {
   XC_EXCHANGE,
   "Perdew, Burke & Ernzerhof SOL",
   XC_FAMILY_GGA,
-  "JP Perdew, et al, Phys. Rev. Lett. 100, 136406 (2008)",
+  {&xc_ref_Perdew2008_136406, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
@@ -289,7 +345,7 @@ const XC(func_info_type) XC(func_info_gga_x_xpbe) = {
   XC_EXCHANGE,
   "Extended PBE by Xu & Goddard III",
   XC_FAMILY_GGA,
-  "X Xu and WA Goddard III, J. Chem. Phys. 121, 4068 (2004)",
+  {&xc_ref_Xu2004_4068, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
@@ -303,7 +359,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbe_jsjr) = {
   XC_EXCHANGE,
   "Reparametrized PBE by Pedroza, Silva & Capelle",
   XC_FAMILY_GGA,
-  "LS Pedroza, AJR da Silva, and K. Capelle, Phys. Rev. B 79, 201106(R) (2009)",
+  {&xc_ref_Pedroza2009_201106, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
@@ -317,7 +373,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbek1_vdw) = {
   XC_EXCHANGE,
   "Reparametrized PBE for vdW",
   XC_FAMILY_GGA,
-  "J Klimes, DR Bowler, and A Michaelides, J. Phys.: Condens. Matter 22, 022201 (2010)",
+  {&xc_ref_Klimes2010_022201, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
@@ -331,7 +387,7 @@ const XC(func_info_type) XC(func_info_gga_x_rge2) = {
   XC_EXCHANGE,
   "Regularized PBE",
   XC_FAMILY_GGA,
-  "A Ruzsinszky, GI Csonka, and G Scuseria, J. Chem. Theory Comput. 5, 763 (2009)",
+  {&xc_ref_Ruzsinszky2009_763, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -345,7 +401,7 @@ const XC(func_info_type) XC(func_info_gga_x_apbe) = {
   XC_EXCHANGE,
   "mu fixed from the semiclassical neutral atom",
   XC_FAMILY_GGA,
-  "LA Constantin, E Fabiano, S Laricchia, and F Della Sala, Phys. Rev. Lett. 106, 186406 (2011)",
+  {&xc_ref_Constantin2011_186406, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -359,7 +415,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbeint) = {
   XC_EXCHANGE,
   "PBE for hybrid interfaces",
   XC_FAMILY_GGA,
-  "E. Fabiano, LA Constantin, and F. Della Sala, Phys. Rev. B 82, 113104 (2010)",
+  {&xc_ref_Fabiano2010_113104, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-12, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -374,7 +430,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbe_tca) = {
   XC_EXCHANGE,
   "PBE revised by Tognetti et al",
   XC_FAMILY_GGA,
-  "V Tognetti, P Cortona, and C Adamo, Chem. Phys. Lett. 460, 536-539 (2008)",
+  {&xc_ref_Tognetti2008_536, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -383,6 +439,89 @@ const XC(func_info_type) XC(func_info_gga_x_pbe_tca) = {
   NULL
 };
 
+const XC(func_info_type) XC(func_info_gga_x_lambda_lo_n) = {
+  XC_GGA_X_LAMBDA_LO_N,
+  XC_EXCHANGE,
+  "lambda_LO(N) version of PBE",
+  XC_FAMILY_GGA,
+  {&xc_ref_Odashima2009_798, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init,
+  NULL, NULL,
+  work_gga_x,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_gga_x_lambda_ch_n) = {
+  XC_GGA_X_LAMBDA_CH_N,
+  XC_EXCHANGE,
+  "lambda_CH(N) version of PBE",
+  XC_FAMILY_GGA,
+  {&xc_ref_Odashima2009_798, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init,
+  NULL, NULL,
+  work_gga_x,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_gga_x_lambda_oc2_n) = {
+  XC_GGA_X_LAMBDA_OC2_N,
+  XC_EXCHANGE,
+  "lambda_OC2(N) version of PBE",
+  XC_FAMILY_GGA,
+  {&xc_ref_Odashima2009_798, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init,
+  NULL, NULL,
+  work_gga_x,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_gga_x_pbe_mol) = {
+  XC_GGA_X_PBE_MOL,
+  XC_EXCHANGE,
+  "Reparametrized PBE by del Campo, Gazquez, Trickey & Vela",
+  XC_FAMILY_GGA,
+  {&xc_ref_delCampo2012_104108, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init, 
+  NULL, NULL,
+  work_gga_x,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_gga_x_bgcp) = {
+  XC_GGA_X_BGCP,
+  XC_EXCHANGE,
+  "Burke, Cancio, Gould, and Pittalis",
+  XC_FAMILY_GGA,
+  {&xc_ref_Burke2014_4834, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init, 
+  NULL, NULL,
+  work_gga_x,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_gga_x_pbefe) = {
+  XC_GGA_X_PBEFE,
+  XC_EXCHANGE,
+  "PBE for formation energies",
+  XC_FAMILY_GGA,
+  {&xc_ref_Perez2015_3844, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init, 
+  NULL, NULL,
+  work_gga_x,
+  NULL
+};
 
 #define XC_KINETIC_FUNCTIONAL
 #include "work_gga_x.c"
@@ -392,7 +531,7 @@ const XC(func_info_type) XC(func_info_gga_k_apbe) = {
   XC_KINETIC,
   "mu fixed from the semiclassical neutral atom",
   XC_FAMILY_GGA,
-  "LA Constantin, E Fabiano, S Laricchia, and F Della Sala, Phys. Rev. Lett. 106, 186406 (2011)",
+  {&xc_ref_Constantin2011_186406, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -406,7 +545,7 @@ const XC(func_info_type) XC(func_info_gga_k_revapbe) = {
   XC_KINETIC,
   "revised APBE",
   XC_FAMILY_GGA,
-  "LA Constantin, E Fabiano, S Laricchia, and F Della Sala, Phys. Rev. Lett. 106, 186406 (2011)",
+  {&xc_ref_Constantin2011_186406, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -420,7 +559,7 @@ const XC(func_info_type) XC(func_info_gga_k_tw1) = {
   XC_KINETIC,
   "Tran and Wesolowski set 1 (Table II)",
   XC_FAMILY_GGA,
-  "F Tran and TA Wesolowski, Int. J. Quant. Chem. 89, 441-446 (2002)",
+  {&xc_ref_Tran2002_441, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -432,9 +571,9 @@ const XC(func_info_type) XC(func_info_gga_k_tw1) = {
 const XC(func_info_type) XC(func_info_gga_k_tw2) = {
   XC_GGA_K_TW2,
   XC_KINETIC,
-  "Tran and Wesolowski set 1 (Table II)",
+  "Tran and Wesolowski set 2 (Table II)",
   XC_FAMILY_GGA,
-  "F Tran and TA Wesolowski, Int. J. Quant. Chem. 89, 441-446 (2002)",
+  {&xc_ref_Tran2002_441, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -446,9 +585,9 @@ const XC(func_info_type) XC(func_info_gga_k_tw2) = {
 const XC(func_info_type) XC(func_info_gga_k_tw3) = {
   XC_GGA_K_TW3,
   XC_KINETIC,
-  "Tran and Wesolowski set 1 (Table II)",
+  "Tran and Wesolowski set 3 (Table II)",
   XC_FAMILY_GGA,
-  "F Tran and TA Wesolowski, Int. J. Quant. Chem. 89, 441-446 (2002)",
+  {&xc_ref_Tran2002_441, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -460,9 +599,9 @@ const XC(func_info_type) XC(func_info_gga_k_tw3) = {
 const XC(func_info_type) XC(func_info_gga_k_tw4) = {
   XC_GGA_K_TW4,
   XC_KINETIC,
-  "Tran and Wesolowski set 1 (Table II)",
+  "Tran and Wesolowski set 4 (Table II)",
   XC_FAMILY_GGA,
-  "F Tran and TA Wesolowski, Int. J. Quant. Chem. 89, 441-446 (2002)",
+  {&xc_ref_Tran2002_441, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -476,7 +615,7 @@ const XC(func_info_type) XC(func_info_gga_k_apbeint) = {
   XC_KINETIC,
   "interpolated version of APBE",
   XC_FAMILY_GGA,
-  "S Laricchia, E Fabiano, LA Constantin, and F Della Sala, J. Chem. Theory Comput. 7, 2439-2451 (2011)",
+  {&xc_ref_Laricchia2011_2439, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -488,9 +627,9 @@ const XC(func_info_type) XC(func_info_gga_k_apbeint) = {
 const XC(func_info_type) XC(func_info_gga_k_revapbeint) = {
   XC_GGA_K_REVAPBEINT,
   XC_KINETIC,
-  "interpolated version of REVAPBE",
+  "interpolated version of revAPBE",
   XC_FAMILY_GGA,
-  "S Laricchia, E Fabiano, LA Constantin, and F Della Sala, J. Chem. Theory Comput. 7, 2439-2451 (2011)",
+  {&xc_ref_Laricchia2011_2439, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
@@ -498,17 +637,3 @@ const XC(func_info_type) XC(func_info_gga_k_revapbeint) = {
   work_gga_k,
   NULL
 };
-
-const XC(func_info_type) XC(func_info_gga_x_pbe_mol) = {
-  XC_GGA_X_PBE_MOL,
-  XC_EXCHANGE,
-  "Reparametrized PBE by del Campo, Gazquez, Trickey & Vela",
-  XC_FAMILY_GGA,
-  "JM del Campo, JL Gazquez, SB Trickey, and A Vela, J. Chem. Phys. 136, 104108 (2012)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
-  gga_x_pbe_init, 
-  NULL, NULL,
-  work_gga_x,
-  NULL
-};
