@@ -50,11 +50,11 @@ void XC(gga_x_sogga11_enhance)
   const FLOAT alpha = mu*X2S*X2S/kappa;
   const FLOAT aa[][6] = {
     {0.50000, -2.95535,  15.7974, -91.1804,  96.2030, 0.18683},   /* SOGGA11   */
-    {0.29925,  3.21638, -3.55605,  7.65852, -11.2830, 5.25813}    /* SOGGA11-X. Values from authors' implementation (MFM 1.8), not original paper! */
+    {0.29925,  3.21638, -3.55605,  7.65852, -11.2830, 5.25813}    /* SOGGA11-X. These coefficients include the factor (1-X) in the functional definition. */
   };
   const FLOAT bb[][6] = {
     {0.50000,  3.50743, -12.9523,  49.7870, -33.2545, -11.1396},  /* SOGGA11   */
-    {0.29925, -2.88595,  3.23617, -2.45393, -3.75495,  3.96613}   /* SOGGA11-X. Values from authors' implementation (MFM 1.8), not original paper! */
+    {0.29925, -2.88595,  3.23617, -2.45393, -3.75495,  3.96613}   /* SOGGA11-X. These coefficients include the factor (1-X) in the functional definition. */
   };
     
   FLOAT f0, df0, d2f0, d3f0, den0, den1, t0, dt0, d2t0, d3t0, t1, dt1, d2t1, d3t1, f1, df1, d2f1, d3f1;
@@ -114,8 +114,7 @@ const XC(func_info_type) XC(func_info_gga_x_sogga11) = {
   XC_EXCHANGE,
   "Second-order generalized gradient approximation 2011",
   XC_FAMILY_GGA,
-  "R Peverati, Y Zhao, and DG Truhlar, J. Phys. Chem. Lett. 2, 1991-1997 (2011)\n"
-  "http://comp.chem.umn.edu/mfm/index.html",
+  {&xc_ref_Peverati2011_1991, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-31, 1e-32, 0.0, 1e-32,
   gga_x_sogga11_init, 
@@ -129,8 +128,7 @@ const XC(func_info_type) XC(func_info_hyb_gga_x_sogga11_x) = {
   XC_EXCHANGE,
   "Hybrid based on SOGGA11 form",
   XC_FAMILY_HYB_GGA,
-  "R Peverati and DG Truhlar, J. Chem. Phys. 135, 191102 (2011)\n"
-  "http://comp.chem.umn.edu/mfm/index.html",
+  {&xc_ref_Peverati2011_191102, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-31, 1e-32, 0.0, 1e-32,
   gga_x_sogga11_init, 
