@@ -150,7 +150,7 @@ const XC(func_info_type) XC(func_info_gga_x_ssb_sw) = {
   XC_EXCHANGE,
   "Swarta, Sola and Bickelhaupt correction to PBE",
   XC_FAMILY_GGA,
-  "M Swart, M Sola, and FM Bickelhaupt, J. Comp. Meth. Sci. Engin. 9, 69 (2009)",
+  {&xc_ref_Swart2009_69, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_ssb_sw_init,
@@ -164,7 +164,7 @@ const XC(func_info_type) XC(func_info_gga_x_ssb) = {
   XC_EXCHANGE,
   "Swarta, Sola and Bickelhaupt",
   XC_FAMILY_GGA,
-  "M Swart, M Sola, and FM Bickelhaupt, J. Chem. Phys. 131, 094103 (2009)",
+  {&xc_ref_Swart2009_094103, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_ssb_init,
@@ -178,7 +178,7 @@ const XC(func_info_type) XC(func_info_gga_x_ssb_d) = {
   XC_EXCHANGE,
   "Swarta, Sola and Bickelhaupt dispersion",
   XC_FAMILY_GGA,
-  "M Swart, M Sola, and FM Bickelhaupt, J. Chem. Phys. 131, 094103 (2009)",
+  {&xc_ref_Swart2009_094103, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_ssb_d_init,
