@@ -149,7 +149,7 @@ const XC(func_info_type) XC(func_info_gga_x_vmt_pbe) = {
   XC_EXCHANGE,
   "Vela, Medel, and Trickey with mu = mu_PBE",
   XC_FAMILY_GGA,
-  "A. Vela, V. Medel, and S. B. Trickey, J. Chem. Phys. 130, 244103 (2009)",
+  {&xc_ref_Vela2009_244103, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_vmt_init, 
@@ -163,7 +163,7 @@ const XC(func_info_type) XC(func_info_gga_x_vmt_ge) = {
   XC_EXCHANGE,
   "Vela, Medel, and Trickey with mu = mu_GE",
   XC_FAMILY_GGA,
-  "A. Vela, V. Medel, and S. B. Trickey, J. Chem. Phys. 130, 244103 (2009)",
+  {&xc_ref_Vela2009_244103, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_vmt_init, 
@@ -177,7 +177,7 @@ const XC(func_info_type) XC(func_info_gga_x_vmt84_pbe) = {
   XC_EXCHANGE,
   "VMT{8,4} with constraint satisfaction with mu = mu_PBE",
   XC_FAMILY_GGA,
-  "A Vela, JC Pacheco-Kato, JL Gazquez, JM del Campo, and SB Trickey, J. Chem. Phys. 136, 144115 (2012)",
+  {&xc_ref_Vela2012_144115, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_vmt_init, 
@@ -191,7 +191,7 @@ const XC(func_info_type) XC(func_info_gga_x_vmt84_ge) = {
   XC_EXCHANGE,
   "VMT{8,4} with constraint satisfaction with mu = mu_GE",
   XC_FAMILY_GGA,
-  "A Vela, JC Pacheco-Kato, JL Gazquez, JM del Campo, and SB Trickey, J. Chem. Phys. 136, 144115 (2012)",
+  {&xc_ref_Vela2012_144115, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_vmt_init, 
