@@ -21,29 +21,35 @@
 #include <stdlib.h>
 #include "util.h"
 
-#define XC_GGA_XC_HCTH_93  161 /* HCTH functional fitted to  93 molecules  */
-#define XC_GGA_XC_HCTH_120 162 /* HCTH functional fitted to 120 molecules  */
-#define XC_GGA_XC_HCTH_147 163 /* HCTH functional fitted to 147 molecules  */
-#define XC_GGA_XC_HCTH_407 164 /* HCTH functional fitted to 407 molecules  */
-#define XC_GGA_XC_B97      167 /* Becke 97                                 */
-#define XC_GGA_XC_B97_1    168 /* Becke 97-1                               */
-#define XC_GGA_XC_B97_2    169 /* Becke 97-2                               */
-#define XC_GGA_XC_B97_D    170 /* Grimme functional to be used with C6 vdW term */
-#define XC_GGA_XC_B97_K    171 /* Boese-Martin for Kinetics                */
-#define XC_GGA_XC_B97_3    172 /* Becke 97-3                               */
-#define XC_GGA_XC_SB98_1a  176 /* Schmider-Becke 98 parameterization 1a    */
-#define XC_GGA_XC_SB98_1b  177 /* Schmider-Becke 98 parameterization 1b    */
-#define XC_GGA_XC_SB98_1c  178 /* Schmider-Becke 98 parameterization 1c    */
-#define XC_GGA_XC_SB98_2a  179 /* Schmider-Becke 98 parameterization 2a    */
-#define XC_GGA_XC_SB98_2b  180 /* Schmider-Becke 98 parameterization 2b    */
-#define XC_GGA_XC_SB98_2c  181 /* Schmider-Becke 98 parameterization 2c    */
-#define XC_GGA_XC_HCTH_A    97 /* HCTH-A                                   */
-#define XC_GGA_XC_B97_GGA1  96 /* Becke 97 GGA-1                           */
-#define XC_GGA_XC_HCTH_P14  95 /* HCTH p=1/4                               */
-#define XC_GGA_XC_HCTH_P76  94 /* HCTH p=7/6                               */
-#define XC_GGA_XC_HCTH_407P 93 /* HCTH/407+                                */
-#define XC_GGA_C_N12        80 /* N12 functional from Minnesota            */
-#define XC_GGA_C_N12_SX     79 /* N12-SX functional from Minnesota         */
+#define XC_GGA_XC_HCTH_93     161 /* HCTH functional fitted to  93 molecules  */
+#define XC_GGA_XC_HCTH_120    162 /* HCTH functional fitted to 120 molecules  */
+#define XC_GGA_XC_HCTH_147    163 /* HCTH functional fitted to 147 molecules  */
+#define XC_GGA_XC_HCTH_407    164 /* HCTH functional fitted to 407 molecules  */
+#define XC_HYB_GGA_XC_B97     407 /* Becke 97                                 */
+#define XC_HYB_GGA_XC_B97_1   408 /* Becke 97-1                               */
+#define XC_HYB_GGA_XC_B97_2   410 /* Becke 97-2                               */
+#define XC_GGA_XC_B97_D       170 /* Grimme functional to be used with C6 vdW term */
+#define XC_HYB_GGA_XC_B97_K   413 /* Boese-Martin for Kinetics                */
+#define XC_HYB_GGA_XC_B97_3   414 /* Becke 97-3                               */
+#define XC_HYB_GGA_XC_SB98_1a 420 /* Schmider-Becke 98 parameterization 1a    */
+#define XC_HYB_GGA_XC_SB98_1b 421 /* Schmider-Becke 98 parameterization 1b    */
+#define XC_HYB_GGA_XC_SB98_1c 422 /* Schmider-Becke 98 parameterization 1c    */
+#define XC_HYB_GGA_XC_SB98_2a 423 /* Schmider-Becke 98 parameterization 2a    */
+#define XC_HYB_GGA_XC_SB98_2b 424 /* Schmider-Becke 98 parameterization 2b    */
+#define XC_HYB_GGA_XC_SB98_2c 425 /* Schmider-Becke 98 parameterization 2c    */
+#define XC_GGA_C_HCTH_A        97 /* HCTH-A                                   */
+#define XC_GGA_XC_B97_GGA1     96 /* Becke 97 GGA-1                           */
+#define XC_GGA_XC_HCTH_P14     95 /* HCTH p=1/4                               */
+#define XC_GGA_XC_HCTH_P76     94 /* HCTH p=7/6                               */
+#define XC_GGA_XC_HCTH_407P    93 /* HCTH/407+                                */
+#define XC_GGA_C_N12           80 /* N12 functional from Minnesota            */
+#define XC_GGA_C_N12_SX        79 /* N12-SX functional from Minnesota         */
+#define XC_HYB_GGA_XC_WB97    463 /* Chai and Head-Gordon                     */
+#define XC_HYB_GGA_XC_WB97X   464 /* Chai and Head-Gordon                     */
+#define XC_HYB_GGA_XC_WB97X_V 466 /* Mardirossian and Head-Gordon             */
+#define XC_HYB_GGA_XC_WB97X_D 471 /* Chai and Head-Gordon                     */
+#define XC_GGA_C_GAM           33 /* GAM functional from Minnesota            */
+#define XC_HYB_GGA_XC_B97_1p  266 /* version of B97 by Cohen and Handy        */
 
 static const FLOAT b97_params[][3][5] = {
   {      /* HCTH/93 */
@@ -51,9 +57,9 @@ static const FLOAT b97_params[][3][5] = {
     {0.222601, -0.0338622,  -0.0125170, -0.802496,  1.55396}, /* Css */
     {0.729974,  3.35287,   -11.5430,     8.08564,  -4.47857}  /* Cab */
   }, {   /* HCTH/120 */
-      {1.09163,  -0.747215,  5.07833,  -4.10746,   1.17173},    /* X   */
-      {0.489508, -0.260699,  0.432917, -1.99247,   2.48531},    /* Css */
-      {0.514730,  6.92982, -24.7073,   23.1098,  -11.3234 }     /* Cab */
+    {1.09163,  -0.747215,  5.07833,  -4.10746,   1.17173},    /* X   */
+    {0.489508, -0.260699,  0.432917, -1.99247,   2.48531},    /* Css */
+    {0.514730,  6.92982, -24.7073,   23.1098,  -11.3234 }     /* Cab */
   }, {   /* HCTH/147 */
     {1.09025, -0.799194,   5.57212, -5.86760,  3.04544 },     /* X   */
     {0.562576, 0.0171436, -1.30636,  1.05747,  0.885429},     /* Css */
@@ -111,7 +117,7 @@ static const FLOAT b97_params[][3][5] = {
     {-0.120163, 2.82332,  -2.59412,  0.0, 0.0},  /* Css */
     { 0.934715, 1.14105,  -5.33398,  0.0, 0.0}   /* Cab */
   }, {   /* HCTH-A  */
-    { 1.09878,  -2.51173,   0.0156233, 0.0,     0.0},  /* X   */
+    { 0.0, 0.0, 0.0, 0.0, 0.0},  /* HTCH-A has a different expression for exchange */
     { 0.0136823, 0.268920, -0.550769,  1.03947, 0.0},  /* Css */
     { 0.836897,  1.72051,  -2.78498,  -4.57504, 0.0}   /* Cab */
   }, {   /* B97 GGA-1  */
@@ -138,7 +144,31 @@ static const FLOAT b97_params[][3][5] = {
     { 0.0,          0.0,          0.0,          0.0,          0.0},          /* X   */ 
     { 2.63373e+00, -1.05450e+00, -7.29853e-01,  4.94024e+00, -7.31760e+00},  /* Css; coefficients flipped in original paper! */
     { 8.33615e-01,  3.24128e+00, -1.06407e+01, -1.60471e+01,  2.51047e+01}   /* Cab; coefficients flipped in original paper! */
-  },
+  }, {   /* wB97  */
+    { 1.00000e+00,  1.13116e+00, -2.74915e+00,  1.20900e+01, -5.71642e+00},  /* X   */
+    { 1.00000e+00, -2.55352e+00,  1.18926e+01, -2.69452e+01,  1.70927e+01},  /* Css */
+    { 1.00000e+00,  3.99051e+00, -1.70066e+01,  1.07292e+00,  8.88211e+00}   /* Cab */
+  }, {   /* wB97X  */
+    { 8.42294e-01,  7.26479e-01,  1.04760e+00, -5.70635e+00,  1.32794e+01},  /* X   */
+    { 1.00000e+00, -4.33879e+00,  1.82308e+01, -3.17430e+01,  1.72901e+01},  /* Css */
+    { 1.00000e+00,  2.37031e+00, -1.13995e+01,  6.58405e+00, -3.78132e+00}   /* Cab */
+  }, {   /* wB97X-V */
+    { 0.833,        0.603,        1.194,        0.0,          0.0        },  /* X   */
+    { 0.556,       -0.257,        0.0,          0.0,          0.0        },  /* Css */
+    { 1.219,       -1.850,        0.0,          0.0,          0.0        }   /* Cab */
+  }, {   /* wB97X-D */
+    { 7.77964e-01,  6.61160e-01,  5.74541e-01, -5.25671e+00,  1.16386e+01},  /* X   */
+    { 1.00000e+00, -6.90539e+00,  3.13343e+01, -5.10533e+01,  2.64423e+01},  /* Css */
+    { 1.00000e+00,  1.79413e+00, -1.20477e+01,  1.40847e+01, -8.50809e+00}   /* Cab */
+  }, {   /* GAM  */
+    { 0.0,       0.0,       0.0,      0.0,       0.0},      /* X   */
+    { 0.231765,  0.575592, -3.43391, -5.77281,   9.52448},  /* Css */
+    { 0.860548, -2.94135,  15.4176,  -5.99825, -23.4119}    /* Cab */
+  }, {   /* B97-1p  */
+    { 0.8773, 0.2149,  1.5204, 0.0, 0.0},  /* X   */
+    { 0.2228, 1.3678, -1.5068, 0.0, 0.0},  /* Css */
+    { 0.9253, 2.0270, -7.3431, 0.0, 0.0}   /* Cab */    
+  }
 };
 
 typedef struct{
@@ -153,40 +183,99 @@ gga_xc_b97_init(XC(func_type) *p)
 
   assert(p != NULL);
 
-  p->n_func_aux  = 1;
-  p->func_aux    = (XC(func_type) **) malloc(1*sizeof(XC(func_type) *));
+  p->n_func_aux  = 2;
+  p->func_aux    = (XC(func_type) **) malloc(2*sizeof(XC(func_type) *));
   p->func_aux[0] = (XC(func_type) *)  malloc(  sizeof(XC(func_type)));
+  p->func_aux[1] = (XC(func_type) *)  malloc(  sizeof(XC(func_type)));
 
-  XC(func_init)(p->func_aux[0], XC_LDA_C_PW, XC_POLARIZED);
+  XC(func_init)(p->func_aux[0], XC_LDA_X,    XC_POLARIZED);
+
+  /* HCTH_A uses the VWN LDA and not PW */
+  if(p->info->number == XC_GGA_C_HCTH_A)
+    XC(func_init)(p->func_aux[1], XC_LDA_C_VWN, XC_POLARIZED);
+  else
+    XC(func_init)(p->func_aux[1], XC_LDA_C_PW, XC_POLARIZED);
 
   assert(p->params == NULL);
   p->params = malloc(sizeof(gga_xc_b97_params));
   params = (gga_xc_b97_params *)(p->params);
 
   switch(p->info->number){
-  case XC_GGA_XC_HCTH_93:   p->func =  0;  break;
-  case XC_GGA_XC_HCTH_120:  p->func =  1;  break;
-  case XC_GGA_XC_HCTH_147:  p->func =  2;  break;
-  case XC_GGA_XC_HCTH_407:  p->func =  3;  break;
-  case XC_GGA_XC_B97:       p->func =  4;  break;
-  case XC_GGA_XC_B97_1:     p->func =  5;  break;
-  case XC_GGA_XC_B97_2:     p->func =  6;  break;
-  case XC_GGA_XC_B97_D:     p->func =  7;  break;
-  case XC_GGA_XC_B97_K:     p->func =  8;  break;
-  case XC_GGA_XC_B97_3:     p->func =  9;  break;
-  case XC_GGA_XC_SB98_1a:   p->func = 10;  break;
-  case XC_GGA_XC_SB98_1b:   p->func = 11;  break;
-  case XC_GGA_XC_SB98_1c:   p->func = 12;  break;
-  case XC_GGA_XC_SB98_2a:   p->func = 13;  break;
-  case XC_GGA_XC_SB98_2b:   p->func = 14;  break;
-  case XC_GGA_XC_SB98_2c:   p->func = 15;  break;
-  case XC_GGA_XC_HCTH_A:    p->func = 16;  break;
-  case XC_GGA_XC_B97_GGA1:  p->func = 17;  break;
-  case XC_GGA_XC_HCTH_P14:  p->func = 18;  break;
-  case XC_GGA_XC_HCTH_P76:  p->func = 19;  break;
-  case XC_GGA_XC_HCTH_407P: p->func = 20;  break;
-  case XC_GGA_C_N12:        p->func = 21;  break;
-  case XC_GGA_C_N12_SX:     p->func = 22;  break;
+  case XC_GGA_XC_HCTH_93:       p->func =  0;  break;
+  case XC_GGA_XC_HCTH_120:      p->func =  1;  break;
+  case XC_GGA_XC_HCTH_147:      p->func =  2;  break;
+  case XC_GGA_XC_HCTH_407:      p->func =  3;  break;
+  case XC_HYB_GGA_XC_B97:       p->func =  4;
+     p->cam_alpha = 0.1943;
+    break;
+  case XC_HYB_GGA_XC_B97_1:     p->func =  5;
+    p->cam_alpha = 0.21;
+    break;
+  case XC_HYB_GGA_XC_B97_2:     p->func =  6;
+    p->cam_alpha = 0.21;
+    break;
+  case XC_GGA_XC_B97_D:         p->func =  7;  break;
+  case XC_HYB_GGA_XC_B97_K:     p->func =  8;
+    p->cam_alpha = 0.42;
+    break;
+  case XC_HYB_GGA_XC_B97_3:     p->func =  9;
+    p->cam_alpha = 2.692880E-01;
+    break;
+  case XC_HYB_GGA_XC_SB98_1a:   p->func = 10;
+    p->cam_alpha = 0.229015;
+    break;
+  case XC_HYB_GGA_XC_SB98_1b:   p->func = 11;
+    p->cam_alpha = 0.199352;
+    break;
+  case XC_HYB_GGA_XC_SB98_1c:   p->func = 12;
+    p->cam_alpha = 0.192416;
+    break;
+  case XC_HYB_GGA_XC_SB98_2a:   p->func = 13;
+    p->cam_alpha = 0.232055;
+    break;
+  case XC_HYB_GGA_XC_SB98_2b:   p->func = 14;
+    p->cam_alpha = 0.237978;
+    break;
+  case XC_HYB_GGA_XC_SB98_2c:   p->func = 15;
+    p->cam_alpha = 0.219847;
+    break;
+  case XC_GGA_C_HCTH_A:         p->func = 16;  break;
+  case XC_GGA_XC_B97_GGA1:      p->func = 17;  break;
+  case XC_GGA_XC_HCTH_P14:      p->func = 18;  break;
+  case XC_GGA_XC_HCTH_P76:      p->func = 19;  break;
+  case XC_GGA_XC_HCTH_407P:     p->func = 20;  break;
+  case XC_GGA_C_N12:            p->func = 21;  break;
+  case XC_GGA_C_N12_SX:         p->func = 22;  break;
+  case XC_HYB_GGA_XC_WB97:      p->func = 23;
+    p->cam_alpha =  1.0;
+    p->cam_omega =  0.4;
+    p->cam_beta  = -1.0;
+    XC(lda_x_set_params)(p->func_aux[0], 4.0/3.0, XC_NON_RELATIVISTIC, 0.4);
+    break;
+  case XC_HYB_GGA_XC_WB97X:     p->func = 24;
+    p->cam_alpha =  1.0;
+    p->cam_omega =  0.3;
+    p->cam_beta  = -(1.0 - 1.57706e-01);
+    XC(lda_x_set_params)(p->func_aux[0], 4.0/3.0, XC_NON_RELATIVISTIC, 0.3);
+    break;
+  case XC_HYB_GGA_XC_WB97X_V:   p->func = 25;
+    p->cam_alpha =  1.0;
+    p->cam_omega =  0.3;
+    p->cam_beta  = -(1.0 - 0.167);
+    XC(lda_x_set_params)(p->func_aux[0], 4.0/3.0, XC_NON_RELATIVISTIC, 0.3);
+    p->nlc_b = 6.0;
+    p->nlc_C = 0.01;
+    break;
+  case XC_HYB_GGA_XC_WB97X_D:   p->func = 26;
+    p->cam_alpha =  1.0;
+    p->cam_omega =  0.2;
+    p->cam_beta  = -(1.0 - 2.22036e-01);
+    XC(lda_x_set_params)(p->func_aux[0], 4.0/3.0, XC_NON_RELATIVISTIC, 0.2);
+    break;
+  case XC_GGA_C_GAM:            p->func = 27;  break;
+  case XC_HYB_GGA_XC_B97_1p:    p->func = 28;
+    p->cam_alpha =  0.15;
+    break;
   default:
     fprintf(stderr, "Internal error in gga_b97\n");
     exit(1);
@@ -226,22 +315,24 @@ static inline void
 func(const XC(func_type) *p, XC(gga_work_c_t) *r)
 {
   static const FLOAT sign[2] = {1.0, -1.0};
-  const FLOAT gamma[3] = {0.004, 0.2, 0.006};
+  const FLOAT gamma[3] = {0.004, 0.2, 0.006}; /* Xs, Css, Cab */
 
-  XC(lda_work_t) LDA[3];
+  XC(lda_work_t) lda_pw[3], lda_x[3];
   const gga_xc_b97_params *params;
-  FLOAT cnst, ldax, x_avg;
+  FLOAT x_avg, aux, aux12;
   FLOAT fx, dfxdx, d2fxdx2, fcpar, dfcpardx, d2fcpardx2, fcper, dfcperdx, d2fcperdx2;
-  FLOAT opz, opz13, dldaxdrs, dldaxdz, d2ldaxdrs2, d2ldaxdrsz, d2ldaxdz2, aux, aux12;
   FLOAT dx_avgdxs[2], d2x_avgdxs2[3];
   int is, js;
  
   params = (gga_xc_b97_params *)(p->params);
 
-  cnst = CBRT(4.0*M_PI/3.0);
-
-  /* first we get the parallel and perpendicular LDAS */
-  XC(lda_stoll) (p->func_aux[0], r->dens, r->zeta, r->order, LDA);
+  /* first we get the parallel and perpendicular LDAs */
+  /* note that HCTH_A uses the VWN LDA and not PW     */
+  if(p->info->number == XC_GGA_C_HCTH_A)
+    XC(lda_stoll) (p->func_aux[1], XC(lda_c_vwn_func), r->dens, r->zeta, r->order, lda_pw);
+  else
+    XC(lda_stoll) (p->func_aux[1], XC(lda_c_pw_func), r->dens, r->zeta, r->order, lda_pw);
+  XC(lda_stoll) (p->func_aux[0], XC(lda_x_func),    r->dens, r->zeta, r->order, lda_x);
 
   /* initialize to zero */
   r->f = 0.0;
@@ -256,42 +347,29 @@ func(const XC(func_type) *p, XC(gga_work_c_t) *r)
 
   /* now we calculate the g functions for exchange and parallel correlation */
   for(is = 0; is < 2; is++){
-    opz   = 1.0 + sign[is]*r->zeta;
-
-    if(r->dens*opz < 2.0*p->info->min_dens) continue;
+    if(r->ds[is] < p->info->min_dens) continue;
 
     XC(mgga_b97_func_g)(params->cc[0], gamma[0], r->xs[is], r->order, &fx, &dfxdx, &d2fxdx2);
     XC(mgga_b97_func_g)(params->cc[1], gamma[1], r->xs[is], r->order, &fcpar, &dfcpardx, &d2fcpardx2);
 
-    opz13 = CBRT(opz);
-
-    ldax = -X_FACTOR_C*opz*opz13/(2.0*M_CBRT2*cnst*r->rs);
-
-    r->f += ldax*fx + LDA[is].zk*fcpar;
+    r->f += lda_x[is].zk*fx + lda_pw[is].zk*fcpar;
 
     if(r->order < 1) continue;
 
-    dldaxdrs = -ldax/r->rs;
-    dldaxdz  = sign[is]*4.0*ldax/(3.0*opz);
-
-    r->dfdrs     += dldaxdrs*fx + LDA[is].dedrs*fcpar;
-    r->dfdz      += dldaxdz *fx + LDA[is].dedz *fcpar;
-    r->dfdxs[is] += ldax*dfxdx  + LDA[is].zk*dfcpardx;
+    r->dfdrs     += lda_x[is].dedrs*fx  + lda_pw[is].dedrs*fcpar;
+    r->dfdz      += lda_x[is].dedz *fx  + lda_pw[is].dedz *fcpar;
+    r->dfdxs[is] += lda_x[is].zk*dfxdx  + lda_pw[is].zk*dfcpardx;
 
     if(r->order < 2) continue;
     
     js = (is == 0) ? 0 : 2;
 
-    d2ldaxdrs2 = -2.0*dldaxdrs/r->rs;
-    d2ldaxdrsz = -dldaxdz/r->rs;
-    d2ldaxdz2  = sign[is]*dldaxdz/(3.0*opz);
-
-    r->d2fdrs2      += d2ldaxdrs2*fx  + LDA[is].d2edrs2*fcpar;
-    r->d2fdrsz      += d2ldaxdrsz*fx  + LDA[is].d2edrsz*fcpar;
-    r->d2fdrsxs[is] += dldaxdrs*dfxdx + LDA[is].dedrs*dfcpardx;
-    r->d2fdz2       += d2ldaxdz2*fx   + LDA[is].d2edz2*fcpar;
-    r->d2fdzxs[is]  += dldaxdz*dfxdx  + LDA[is].dedz*dfcpardx;
-    r->d2fdxs2[js]  += ldax*d2fxdx2   + LDA[is].zk*d2fcpardx2;
+    r->d2fdrs2      += lda_x[is].d2edrs2*fx  + lda_pw[is].d2edrs2*fcpar;
+    r->d2fdrsz      += lda_x[is].d2edrsz*fx  + lda_pw[is].d2edrsz*fcpar;
+    r->d2fdrsxs[is] += lda_x[is].dedrs*dfxdx + lda_pw[is].dedrs*dfcpardx;
+    r->d2fdz2       += lda_x[is].d2edz2*fx   + lda_pw[is].d2edz2*fcpar;
+    r->d2fdzxs[is]  += lda_x[is].dedz*dfxdx  + lda_pw[is].dedz*dfcpardx;
+    r->d2fdxs2[js]  += lda_x[is].zk*d2fxdx2  + lda_pw[is].zk*d2fcpardx2;
   }
 
   /* and now we add the opposite-spin contribution */
@@ -301,17 +379,17 @@ func(const XC(func_type) *p, XC(gga_work_c_t) *r)
 
   XC(mgga_b97_func_g)(params->cc[2], gamma[2], x_avg, r->order, &fcper, &dfcperdx, &d2fcperdx2);
 
-  r->f += LDA[2].zk*fcper;
+  r->f += lda_pw[2].zk*fcper;
 
   if(r->order < 1) return;
 
   dx_avgdxs[0] = r->xs[0]/(aux12*M_SQRT2);
   dx_avgdxs[1] = r->xs[1]/(aux12*M_SQRT2);
 
-  r->dfdrs    += LDA[2].dedrs*fcper;
-  r->dfdz     += LDA[2].dedz *fcper;
-  r->dfdxs[0] += LDA[2].zk*dfcperdx*dx_avgdxs[0];
-  r->dfdxs[1] += LDA[2].zk*dfcperdx*dx_avgdxs[1];
+  r->dfdrs    += lda_pw[2].dedrs*fcper;
+  r->dfdz     += lda_pw[2].dedz *fcper;
+  r->dfdxs[0] += lda_pw[2].zk*dfcperdx*dx_avgdxs[0];
+  r->dfdxs[1] += lda_pw[2].zk*dfcperdx*dx_avgdxs[1];
 
   if(r->order < 2) return;
 
@@ -319,27 +397,27 @@ func(const XC(func_type) *p, XC(gga_work_c_t) *r)
   d2x_avgdxs2[1] = -r->xs[0]*r->xs[1]/(aux*aux12*M_SQRT2);
   d2x_avgdxs2[2] =  r->xs[0]*r->xs[0]/(aux*aux12*M_SQRT2);
 
-  r->d2fdrs2     += LDA[2].d2edrs2*fcper;
-  r->d2fdrsz     += LDA[2].d2edrsz*fcper;
-  r->d2fdrsxs[0] += LDA[2].dedrs*dfcperdx*dx_avgdxs[0];
-  r->d2fdrsxs[1] += LDA[2].dedrs*dfcperdx*dx_avgdxs[1];
-  r->d2fdz2      += LDA[2].d2edz2*fcper;
-  r->d2fdzxs[0]  += LDA[2].dedz*dfcperdx*dx_avgdxs[0];
-  r->d2fdzxs[1]  += LDA[2].dedz*dfcperdx*dx_avgdxs[1];
-  r->d2fdxs2[0]  += LDA[2].zk*(d2fcperdx2*dx_avgdxs[0]*dx_avgdxs[0] + dfcperdx*d2x_avgdxs2[0]);
-  r->d2fdxs2[1]  += LDA[2].zk*(d2fcperdx2*dx_avgdxs[0]*dx_avgdxs[1] + dfcperdx*d2x_avgdxs2[1]);
-  r->d2fdxs2[2]  += LDA[2].zk*(d2fcperdx2*dx_avgdxs[1]*dx_avgdxs[1] + dfcperdx*d2x_avgdxs2[2]);
+  r->d2fdrs2     += lda_pw[2].d2edrs2*fcper;
+  r->d2fdrsz     += lda_pw[2].d2edrsz*fcper;
+  r->d2fdrsxs[0] += lda_pw[2].dedrs*dfcperdx*dx_avgdxs[0];
+  r->d2fdrsxs[1] += lda_pw[2].dedrs*dfcperdx*dx_avgdxs[1];
+  r->d2fdz2      += lda_pw[2].d2edz2*fcper;
+  r->d2fdzxs[0]  += lda_pw[2].dedz*dfcperdx*dx_avgdxs[0];
+  r->d2fdzxs[1]  += lda_pw[2].dedz*dfcperdx*dx_avgdxs[1];
+  r->d2fdxs2[0]  += lda_pw[2].zk*(d2fcperdx2*dx_avgdxs[0]*dx_avgdxs[0] + dfcperdx*d2x_avgdxs2[0]);
+  r->d2fdxs2[1]  += lda_pw[2].zk*(d2fcperdx2*dx_avgdxs[0]*dx_avgdxs[1] + dfcperdx*d2x_avgdxs2[1]);
+  r->d2fdxs2[2]  += lda_pw[2].zk*(d2fcperdx2*dx_avgdxs[1]*dx_avgdxs[1] + dfcperdx*d2x_avgdxs2[2]);
 }
 
 
 #include "work_gga_c.c"
 
-const XC(func_info_type) XC(func_info_gga_xc_b97) = {
-  XC_GGA_XC_B97,
+const XC(func_info_type) XC(func_info_hyb_gga_xc_b97) = {
+  XC_HYB_GGA_XC_B97,
   XC_EXCHANGE_CORRELATION,
   "Becke 97",
-  XC_FAMILY_GGA,
-  "AD Becke, J. Chem. Phys. 107, 8554 (1997)",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Becke1997_8554, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -349,12 +427,12 @@ const XC(func_info_type) XC(func_info_gga_xc_b97) = {
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_xc_b97_1) = {
-  XC_GGA_XC_B97_1,
+const XC(func_info_type) XC(func_info_hyb_gga_xc_b97_1) = {
+  XC_HYB_GGA_XC_B97_1,
   XC_EXCHANGE_CORRELATION,
   "Becke 97-1",
-  XC_FAMILY_GGA,
-  "FA Hamprecht, AJ Cohen, DJ Tozer, and NC Handy, J. Chem. Phys. 109, 6264 (1998)",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Hamprecht1998_6264, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init,
@@ -364,12 +442,12 @@ const XC(func_info_type) XC(func_info_gga_xc_b97_1) = {
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_xc_b97_2) = {
-  XC_GGA_XC_B97_2,
+const XC(func_info_type) XC(func_info_hyb_gga_xc_b97_2) = {
+  XC_HYB_GGA_XC_B97_2,
   XC_EXCHANGE_CORRELATION,
   "Becke 97-2",
-  XC_FAMILY_GGA,
-  "PJ Wilson, TJ Bradley, and DJ Tozer, J. Chem. Phys. 115, 9233 (2001)",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Wilson2001_9233, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -384,7 +462,7 @@ const XC(func_info_type) XC(func_info_gga_xc_b97_d) = {
   XC_EXCHANGE_CORRELATION,
   "Becke 97-D",
   XC_FAMILY_GGA,
-  "S Grimme, J. Comput. Chem. 27, 1787 (2006)",
+  {&xc_ref_Grimme2006_1787, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -394,12 +472,12 @@ const XC(func_info_type) XC(func_info_gga_xc_b97_d) = {
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_xc_b97_k) = {
-  XC_GGA_XC_B97_K,
+const XC(func_info_type) XC(func_info_hyb_gga_xc_b97_k) = {
+  XC_HYB_GGA_XC_B97_K,
   XC_EXCHANGE_CORRELATION,
   "Boese-Martin for Kinetics",
-  XC_FAMILY_GGA,
-  "AD Boese and JML Martin, J. Chem. Phys., Vol. 121, 3405 (2004)",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Boese2004_3405, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -409,12 +487,12 @@ const XC(func_info_type) XC(func_info_gga_xc_b97_k) = {
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_xc_b97_3) = {
-  XC_GGA_XC_B97_3,
+const XC(func_info_type) XC(func_info_hyb_gga_xc_b97_3) = {
+  XC_HYB_GGA_XC_B97_3,
   XC_EXCHANGE_CORRELATION,
   "Becke 97-3",
-  XC_FAMILY_GGA,
-  "TW Keal and DJ Tozer, J. Chem. Phys. 123, 121103 (2005)",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Keal2005_121103, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -429,7 +507,7 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_93) = {
   XC_EXCHANGE_CORRELATION,
   "HCTH/93",
   XC_FAMILY_GGA,
-  "FA Hamprecht, AJ Cohen, DJ Tozer, and NC Handy, J. Chem. Phys. 109, 6264 (1998)",
+  {&xc_ref_Hamprecht1998_6264, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -444,7 +522,7 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_120) = {
   XC_EXCHANGE_CORRELATION,
   "HCTH/120",
   XC_FAMILY_GGA,
-  "AD Boese, NL Doltsinis, NC Handy, and M Sprik, J. Chem. Phys. 112, 1670 (2000)",
+  {&xc_ref_Boese2000_1670, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -459,7 +537,7 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_147) = {
   XC_EXCHANGE_CORRELATION,
   "HCTH/147",
   XC_FAMILY_GGA,
-  "AD Boese, NL Doltsinis, NC Handy, and M Sprik, J. Chem. Phys. 112, 1670 (2000)",
+  {&xc_ref_Boese2000_1670, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -474,7 +552,7 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_407) = {
   XC_EXCHANGE_CORRELATION,
   "HCTH/407",
   XC_FAMILY_GGA,
-  "AD Boese and NC Handy, J. Chem. Phys. 114, 5497 (2001)",
+  {&xc_ref_Boese2001_5497, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -484,12 +562,12 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_407) = {
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_xc_sb98_1a) = {
-  XC_GGA_XC_SB98_1a,
+const XC(func_info_type) XC(func_info_hyb_gga_xc_sb98_1a) = {
+  XC_HYB_GGA_XC_SB98_1a,
   XC_EXCHANGE_CORRELATION,
   "SB98 (1a)",
-  XC_FAMILY_GGA,
-  "HL Schmider and AD Becke, J. Chem. Phys. 108, 9624 (1998)",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Schmider1998_9624, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -499,12 +577,12 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_1a) = {
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_xc_sb98_1b) = {
-  XC_GGA_XC_SB98_1b,
+const XC(func_info_type) XC(func_info_hyb_gga_xc_sb98_1b) = {
+  XC_HYB_GGA_XC_SB98_1b,
   XC_EXCHANGE_CORRELATION,
   "SB98 (1b)",
-  XC_FAMILY_GGA,
-  "HL Schmider and AD Becke, J. Chem. Phys. 108, 9624 (1998)",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Schmider1998_9624, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -514,12 +592,12 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_1b) = {
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_xc_sb98_1c) = {
-  XC_GGA_XC_SB98_1c,
+const XC(func_info_type) XC(func_info_hyb_gga_xc_sb98_1c) = {
+  XC_HYB_GGA_XC_SB98_1c,
   XC_EXCHANGE_CORRELATION,
   "SB98 (1c)",
-  XC_FAMILY_GGA,
-  "HL Schmider and AD Becke, J. Chem. Phys. 108, 9624 (1998)",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Schmider1998_9624, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -529,12 +607,12 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_1c) = {
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_xc_sb98_2a) = {
-  XC_GGA_XC_SB98_2a,
+const XC(func_info_type) XC(func_info_hyb_gga_xc_sb98_2a) = {
+  XC_HYB_GGA_XC_SB98_2a,
   XC_EXCHANGE_CORRELATION,
   "SB98 (2a)",
-  XC_FAMILY_GGA,
-  "HL Schmider and AD Becke, J. Chem. Phys. 108, 9624 (1998)",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Schmider1998_9624, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -544,12 +622,12 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_2a) = {
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_xc_sb98_2b) = {
-  XC_GGA_XC_SB98_2b,
+const XC(func_info_type) XC(func_info_hyb_gga_xc_sb98_2b) = {
+  XC_HYB_GGA_XC_SB98_2b,
   XC_EXCHANGE_CORRELATION,
   "SB98 (2b)",
-  XC_FAMILY_GGA,
-  "HL Schmider and AD Becke, J. Chem. Phys. 108, 9624 (1998)",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Schmider1998_9624, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -559,12 +637,12 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_2b) = {
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_xc_sb98_2c) = {
-  XC_GGA_XC_SB98_2c,
+const XC(func_info_type) XC(func_info_hyb_gga_xc_sb98_2c) = {
+  XC_HYB_GGA_XC_SB98_2c,
   XC_EXCHANGE_CORRELATION,
   "SB98 (2c)",
-  XC_FAMILY_GGA,
-  "HL Schmider and AD Becke, J. Chem. Phys. 108, 9624 (1998)",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Schmider1998_9624, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -574,12 +652,12 @@ const XC(func_info_type) XC(func_info_gga_xc_sb98_2c) = {
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_xc_hcth_a) = {
-  XC_GGA_XC_HCTH_A,
-  XC_EXCHANGE_CORRELATION,
+const XC(func_info_type) XC(func_info_gga_c_hcth_a) = {
+  XC_GGA_C_HCTH_A,
+  XC_CORRELATION,
   "HCTH-A",
   XC_FAMILY_GGA,
-  "FA Hamprecht, AJ Cohen, DJ Tozer, and NC Handy, J. Chem. Phys. 109, 6264 (1998)",
+  {&xc_ref_Hamprecht1998_6264, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -594,7 +672,7 @@ const XC(func_info_type) XC(func_info_gga_xc_b97_gga1) = {
   XC_EXCHANGE_CORRELATION,
   "Becke 97 GGA-1",
   XC_FAMILY_GGA,
-  "AJ Cohen and NC Handy, Chem. Phys. Lett. 316, 160-166 (2000)",
+  {&xc_ref_Cohen2000_160, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -608,8 +686,8 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_p14) = {
   XC_GGA_XC_HCTH_P14,
   XC_EXCHANGE_CORRELATION,
   "HCTH p=1/4",
-  XC_FAMILY_GGA,
-  "G Menconi, PJ Wilson, and DJ Tozer, J. Chem. Phys. 114, 3958 (2001)",
+  XC_FAMILY_GGA, 
+  {&xc_ref_Menconi2001_3958, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -622,9 +700,9 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_p14) = {
 const XC(func_info_type) XC(func_info_gga_xc_hcth_p76) = {
   XC_GGA_XC_HCTH_P76,
   XC_EXCHANGE_CORRELATION,
-  "HCTH p=1/4",
+  "HCTH p=7/6",
   XC_FAMILY_GGA,
-  "G Menconi, PJ Wilson, and DJ Tozer, J. Chem. Phys. 114, 3958 (2001)",
+  {&xc_ref_Menconi2001_3958, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -639,7 +717,7 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_407p) = {
   XC_EXCHANGE_CORRELATION,
   "HCTH/407+",
   XC_FAMILY_GGA,
-  "AD Boese, A Chandra, JML Martin, and Dominik Marx, J. Chem. Phys. 119, 5965 (2003)",
+  {&xc_ref_Boese2003_5965, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-23, 1e-32, 0.0, 1e-32,
   gga_xc_b97_init, 
@@ -649,12 +727,12 @@ const XC(func_info_type) XC(func_info_gga_xc_hcth_407p) = {
   NULL
 };
 
-XC(func_info_type) XC(func_info_gga_c_n12) = {
+const XC(func_info_type) XC(func_info_gga_c_n12) = {
   XC_GGA_C_N12,
   XC_CORRELATION,
-  "N12 functional of Minnesota",
+  "Minnesota N12 functional",
   XC_FAMILY_GGA,
-  "R Peverati and DG Truhlar, J. Chem. Theory Comput. 8, 2310-2319 (2012)",
+  {&xc_ref_Peverati2012_2310, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   gga_xc_b97_init,
@@ -663,12 +741,12 @@ XC(func_info_type) XC(func_info_gga_c_n12) = {
   NULL
 };
 
-XC(func_info_type) XC(func_info_gga_c_n12_sx) = {
+const XC(func_info_type) XC(func_info_gga_c_n12_sx) = {
   XC_GGA_C_N12_SX,
   XC_CORRELATION,
-  "N12-SX functional of Minnesota",
+  "Minnesota N12-SX functional",
   XC_FAMILY_GGA,
-  "R Peverati and DG Truhlar, Phys. Chem. Chem. Phys. 14, 16187-16191 (2012)",
+  {&xc_ref_Peverati2012_16187, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   gga_xc_b97_init,
@@ -677,3 +755,92 @@ XC(func_info_type) XC(func_info_gga_c_n12_sx) = {
   NULL
 };
 
+const XC(func_info_type) XC(func_info_hyb_gga_xc_wb97) = {
+  XC_HYB_GGA_XC_WB97,
+  XC_EXCHANGE_CORRELATION,
+  "wB97 range-separated functional",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Chai2008_084106, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HYB_CAM,
+  1e-23, 1e-32, 0.0, 1e-32,
+  gga_xc_b97_init, 
+  NULL,
+  NULL,
+  work_gga_c,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_hyb_gga_xc_wb97x) = {
+  XC_HYB_GGA_XC_WB97X,
+  XC_EXCHANGE_CORRELATION,
+  "wB97X range-separated functional",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Chai2008_084106, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HYB_CAM,
+  1e-23, 1e-32, 0.0, 1e-32,
+  gga_xc_b97_init, 
+  NULL,
+  NULL,
+  work_gga_c,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_hyb_gga_xc_wb97x_v) = {
+  XC_HYB_GGA_XC_WB97X_V,
+  XC_EXCHANGE_CORRELATION,
+  "wB97X range-separated functional",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Mardirossian2014_9904, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HYB_CAM | XC_FLAGS_VV10,
+  1e-23, 1e-32, 0.0, 1e-32,
+  gga_xc_b97_init, 
+  NULL,
+  NULL,
+  work_gga_c,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_hyb_gga_xc_wb97x_d) = {
+  XC_HYB_GGA_XC_WB97X_D,
+  XC_EXCHANGE_CORRELATION,
+  "wB97D range-separated functional",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Chai2008_6615, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HYB_CAM,
+  1e-23, 1e-32, 0.0, 1e-32,
+  gga_xc_b97_init, 
+  NULL,
+  NULL,
+  work_gga_c,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_gga_c_gam) = {
+  XC_GGA_C_GAM,
+  XC_CORRELATION,
+  "GAM functional from Minnesota",
+  XC_FAMILY_GGA,
+  {&xc_ref_Yu2015_12146, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_DEVELOPMENT,
+  1e-23, 1e-32, 0.0, 1e-32,
+  gga_xc_b97_init, 
+  NULL,
+  NULL,
+  work_gga_c,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_hyb_gga_xc_b97_1p) = {
+  XC_HYB_GGA_XC_B97_1p,
+  XC_EXCHANGE_CORRELATION,
+  "version of B97 by Cohen and Handy",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Cohen2000_160, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  1e-23, 1e-32, 0.0, 1e-32,
+  gga_xc_b97_init, 
+  NULL,
+  NULL,
+  work_gga_c,
+  NULL
+};
