@@ -45,7 +45,7 @@ const XC(func_info_type) XC(func_info_gga_xc_edf1) = {
   XC_EXCHANGE_CORRELATION,
   "EDF1",
   XC_FAMILY_GGA,
-  "RD Adamson, PMW Gill, and JA Pople, Chem. Phys. Lett. 284 6 (1998)",
+  {&xc_ref_Adamson1998_6, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_xc_edf1_init, 
@@ -70,7 +70,7 @@ const XC(func_info_type) XC(func_info_gga_x_optpbe_vdw) = {
   XC_EXCHANGE,
   "Reparametrized PBE for vdW",
   XC_FAMILY_GGA,
-  "J Klimes, DR Bowler, and A Michaelides, J. Phys.: Condens. Matter 22, 022201 (2010)",
+  {&xc_ref_Klimes2010_022201, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_optpbe_vdw_init, 
@@ -94,7 +94,7 @@ const XC(func_info_type) XC(func_info_gga_xc_mohlyp) = {
   XC_EXCHANGE_CORRELATION,
   "Functional for organometallic chemistry",
   XC_FAMILY_GGA,
-  "NE Schultz, Y Zhao, DGJ Truhlar, Phys. Chem. A, 109, 11127 (2005)",
+  {&xc_ref_Schultz2005_11127, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_xc_mohlyp_init,
@@ -117,7 +117,7 @@ const XC(func_info_type) XC(func_info_gga_xc_mohlyp2) = {
   XC_EXCHANGE_CORRELATION,
   "Functional for barrier heights",
   XC_FAMILY_GGA,
-  "J Zheng, Y Zhao, DGJ Truhlar, Chem. Theory. Comput. 5, 808 (2009)",
+  {&xc_ref_Zheng2009_808, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_xc_mohlyp2_init,
@@ -141,8 +141,7 @@ const XC(func_info_type) XC(func_info_gga_x_sogga) = {
   XC_EXCHANGE,
   "Second-order generalized gradient approximation",
   XC_FAMILY_GGA,
-  "Y Zhao and DG Truhlar, J. Chem. Phys. 128, 184109 (2008)\n"
-  "http://comp.chem.umn.edu/mfm/index.html",
+  {&xc_ref_Zhao2008_184109, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-31, 1e-32, 0.0, 1e-32,
   gga_x_sogga_init,
