@@ -22,7 +22,7 @@
 #include "util.h"
 
 #define XC_HYB_GGA_XC_CAM_B3LYP        433 /* CAM version of B3LYP */
-#define XC_HYB_GGA_XC_TUNED_CAM_B3LYP  434 /* CAM version of B3LYP tunes for excitations*/
+#define XC_HYB_GGA_XC_TUNED_CAM_B3LYP  434 /* CAM version of B3LYP tuned for excitations*/
 
 void
 XC(hyb_gga_xc_cam_b3lyp_init)(XC(func_type) *p)
@@ -70,7 +70,7 @@ const XC(func_info_type) XC(func_info_hyb_gga_xc_cam_b3lyp) = {
   XC_EXCHANGE_CORRELATION,
   "CAM version of B3LYP",
   XC_FAMILY_HYB_GGA,
-  "T Yanai, DP Tew, NC Handy, Chem. Phys. Lett. 393, 51-57 (2004)",
+  {&xc_ref_Yanai2004_51, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HYB_CAM | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 0.0, 1e-32,
   XC(hyb_gga_xc_cam_b3lyp_init),
@@ -81,9 +81,9 @@ const XC(func_info_type) XC(func_info_hyb_gga_xc_cam_b3lyp) = {
 const XC(func_info_type) XC(func_info_hyb_gga_xc_tuned_cam_b3lyp) = {
   XC_HYB_GGA_XC_TUNED_CAM_B3LYP,
   XC_EXCHANGE_CORRELATION,
-  "CAM version of B3LYP",
+  "CAM version of B3LYP, tuned for excitations and properties",
   XC_FAMILY_HYB_GGA,
-  "K Okuno, Y Shigeta, R Kishi, H Miyasaka, M Nakano, J. Photochem. Photobiol., A 235, 29-34 (2012)",
+  {&xc_ref_Okuno2012_29, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HYB_CAM | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 0.0, 1e-32,
   XC(hyb_gga_xc_cam_b3lyp_init),
