@@ -33,7 +33,7 @@ XC(hyb_gga_xc_camy_blyp_init)(XC(func_type) *p)
      convention for alpha and beta.  In libxc, alpha is the weight for
      HF exchange, which in the original reference is alpha+beta.
   */
-  FLOAT alpha, beta, omega;
+  static FLOAT alpha, beta, omega;
   
   alpha = 1.00;
   beta  =-0.80;
@@ -46,7 +46,7 @@ XC(hyb_gga_xc_camy_blyp_init)(XC(func_type) *p)
   funcs_coef[2] = 1.0;
 
   XC(mix_init)(p, 3, funcs_id, funcs_coef);
-  XC(gga_x_sfat_set_params)(p->func_aux[1], XC_GGA_X_B88, p->cam_omega);
+  XC(gga_x_sfat_set_params)(p->func_aux[1], XC_GGA_X_B88, omega);
 
   p->cam_omega=omega;
   p->cam_alpha=alpha;
@@ -58,8 +58,8 @@ const XC(func_info_type) XC(func_info_hyb_gga_xc_camy_blyp) = {
   XC_EXCHANGE_CORRELATION,
   "CAMY version of BLYP",
   XC_FAMILY_HYB_GGA,
-  "Y Akinaga, S Ten-no, Chem. Phys. Lett. 462, 348-351 (2008)",
-  XC_FLAGS_3D | XC_FLAGS_HYB_CAM | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
+  {&xc_ref_Akinaga2008_348, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HYB_CAMY | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 0.0, 1e-32,
   XC(hyb_gga_xc_camy_blyp_init),
   NULL, NULL, NULL, NULL
