@@ -22,7 +22,7 @@
 #include "util.h"
 
 #define XC_HYB_GGA_XC_O3LYP   404 /* hybrid using the optx functional */
-#define XC_HYB_GGA_XC_X3LYP   411 /* maybe the best hybrid */
+#define XC_HYB_GGA_XC_X3LYP   411 /* hybrid by Xu and Goddard */
 
 
 /*************************************************************/
@@ -52,7 +52,7 @@ const XC(func_info_type) XC(func_info_hyb_gga_xc_o3lyp) = {
   XC_EXCHANGE_CORRELATION,
   "O3LYP",
   XC_FAMILY_HYB_GGA,
-  "AJ Cohen, NC Handy, Mol. Phys. 99 607 (2001)",
+  {&xc_ref_Cohen2001_607, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_xc_o3lyp_init,
@@ -70,7 +70,7 @@ gga_xc_x3lyp_init(XC(func_type) *p)
   static int funcs_id[5] = {XC_LDA_X, XC_GGA_X_B88, XC_GGA_X_PW91, XC_LDA_C_VWN_RPA, XC_GGA_C_LYP};
   FLOAT funcs_coef[5];
 
-  funcs_coef[0] = 1.0 - a0 - ax*(a1 + a2);;
+  funcs_coef[0] = 1.0 - a0 - ax*(a1 + a2);
   funcs_coef[1] = ax*a1;
   funcs_coef[2] = ax*a2;
   funcs_coef[3] = 1.0 - ac;
@@ -85,7 +85,7 @@ const XC(func_info_type) XC(func_info_hyb_gga_xc_x3lyp) = {
   XC_EXCHANGE_CORRELATION,
   "X3LYP",
   XC_FAMILY_HYB_GGA,
-  "X Xu, WA Goddard, III, PNAS 101, 2673 (2004)",
+  {&xc_ref_Xu2004_2673, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_xc_x3lyp_init,
