@@ -23,6 +23,7 @@
 
 #define XC_HYB_GGA_XC_PBEH    406 /* aka PBE0 or PBE1PBE */
 #define XC_HYB_GGA_XC_PBE0_13 456 /* PBE0-1/3            */
+#define XC_HYB_GGA_XC_HPBEINT 472 /* hPBEint             */
 
 static void
 hyb_gga_xc_pbeh_init(XC(func_type) *p)
@@ -48,15 +49,13 @@ const XC(func_info_type) XC(func_info_hyb_gga_xc_pbeh) = {
   XC_EXCHANGE_CORRELATION,
   "PBEH (PBE0)",
   XC_FAMILY_HYB_GGA,
-  "C Adamo and V Barone, J. Chem. Phys. 110, 6158 (1999)\n"
-  "M. Ernzerhof, G. E. Scuseria, J. Chem. Phys. 110, 5029 (1999)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
+  {&xc_ref_Adamo1999_6158, &xc_ref_Ernzerhof1999_5029, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   hyb_gga_xc_pbeh_init,
   NULL, NULL, NULL, NULL /* this is taken care by the generic routine */
 };
 
-
 static void
 hyb_gga_xc_pbe0_13_init(XC(func_type) *p)
 {
@@ -72,11 +71,33 @@ const XC(func_info_type) XC(func_info_hyb_gga_xc_pbe0_13) = {
   XC_EXCHANGE_CORRELATION,
   "PBE0-1/3",
   XC_FAMILY_HYB_GGA,
-  "P Cortona, J. Chem. Phys. 136, 086101 (2012)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
+  {&xc_ref_Cortona2012_086101, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 0.0, 1e-32,
   hyb_gga_xc_pbe0_13_init,
   NULL, NULL, NULL, NULL /* this is taken care by the generic routine */
 };
 
+static void
+hyb_gga_xc_hpbeint_init(XC(func_type) *p)
+{
+  static int   funcs_id  [2] = {XC_GGA_X_PBEINT, XC_GGA_C_PBEINT};
+  static FLOAT funcs_coef[2] = {1.0 - 1.0/6.0, 1.0};
+
+  XC(mix_init)(p, 2, funcs_id, funcs_coef);
+  p->cam_alpha = 1.0/6.0;
+}
+
+const XC(func_info_type) XC(func_info_hyb_gga_xc_hpbeint) = {
+  XC_HYB_GGA_XC_HPBEINT,
+  XC_EXCHANGE_CORRELATION,
+  "hPBEint",
+  XC_FAMILY_HYB_GGA,
+  {&xc_ref_Fabiano2013_673, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_DEVELOPMENT,
+  1e-32, 1e-32, 0.0, 1e-32,
+  hyb_gga_xc_hpbeint_init,
+  NULL, NULL, NULL, NULL /* this is taken care by the generic routine */
+};
+
 
