@@ -206,7 +206,7 @@ const XC(func_info_type) XC(func_info_lda_c_1d_csc) = {
   XC_CORRELATION,
   "Casula, Sorella & Senatore",
   XC_FAMILY_LDA,
-  "M Casula, S Sorella, and G Senatore, Phys. Rev. B 74, 245427 (2006)",
+  {&xc_ref_Casula2006_245427, NULL, NULL, NULL, NULL},
   XC_FLAGS_1D |  XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 0.0, 0.0, 1e-32,
   lda_c_1d_csc_init,    /* init */
