@@ -134,7 +134,7 @@ const XC(func_info_type) XC(func_info_lda_c_2d_prm) = {
   XC_CORRELATION,
   "PRM (for 2D systems)",
   XC_FAMILY_LDA,
-  "S Pittalis, E Rasanen, and MAL Marques, Phys. Rev. B 78, 195322 (2008)",
+  {&xc_ref_Pittalis2008_195322, NULL, NULL, NULL, NULL},
   XC_FLAGS_2D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 0.0, 0.0, 1e-32,
   lda_c_2d_prm_init,
