@@ -58,7 +58,7 @@ const XC(func_info_type) XC(func_info_lda_c_wigner) = {
   XC_CORRELATION,
   "Wigner",
   XC_FAMILY_LDA,
-  "EP Wigner, Trans. Faraday Soc. 34, 678 (1938)",
+  {&xc_ref_Wigner1938_678, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 0.0, 0.0, 1e-32,
   NULL,     /* init */
