@@ -78,8 +78,7 @@ const XC(func_info_type) XC(func_info_lda_x_2d) = {
   XC_EXCHANGE,
   "Slater exchange",
   XC_FAMILY_LDA,
-  "PAM Dirac, Proceedings of the Cambridge Philosophical Society 26, 376 (1930)\n"
-  "F Bloch, Zeitschrift fuer Physik 57, 545 (1929)",
+  {&xc_ref_Dirac1930_376, &xc_ref_Bloch1929_545, NULL, NULL, NULL},
   XC_FLAGS_2D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 0.0, 0.0, 1e-32,
   NULL, 
