@@ -72,7 +72,7 @@ func(const XC(func_type) *p, XC(mgga_work_c_t) *r)
   params = (mgga_c_bc95_params *) (p->params);  
 
   /* first we get the parallel and perpendicular LDAS */
-  XC(lda_stoll) (p->func_aux[0], r->dens, r->zeta, r->order, LDA);
+  XC(lda_stoll) (p->func_aux[0], XC(lda_c_pw_func), r->dens, r->zeta, r->order, LDA);
 
   /* initialize to zero */
   r->f = 0.0;
@@ -127,12 +127,12 @@ func(const XC(func_type) *p, XC(mgga_work_c_t) *r)
 
 #include "work_mgga_c.c"
 
-XC(func_info_type) XC(func_info_mgga_c_bc95) = {
+const XC(func_info_type) XC(func_info_mgga_c_bc95) = {
   XC_MGGA_C_BC95,
   XC_CORRELATION,
   "Becke correlation 95",
   XC_FAMILY_MGGA,
-  "AD Becke, J. Chem. Phys. 104, 1040 (1996)",
+  {&xc_ref_Becke1996_1040, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_c_bc95_init,
