@@ -23,12 +23,13 @@
 #include "util.h"
 
 #define XC_MGGA_C_VSXC          232 /* VSxc from Van Voorhis and Scuseria (correlation part) */
-#define XC_MGGA_C_M05           237 /* M05 functional of Minnesota */
-#define XC_MGGA_C_M05_2X        238 /* M05-2X functional of Minnesota */
-#define XC_MGGA_C_M06_L         233 /* M06-Local functional of Minnesota */
-#define XC_MGGA_C_M06_HF        234 /* M06-HF functional of Minnesota */
-#define XC_MGGA_C_M06           235 /* M06 functional of Minnesota */
-#define XC_MGGA_C_M06_2X        236 /* M06-2X functional of Minnesota */
+#define XC_MGGA_C_M05           237 /* Worker for M05 functional           */
+#define XC_MGGA_C_M05_2X        238 /* Worker for M05-2X functional        */
+#define XC_MGGA_C_M06_L         233 /* M06-Local functional from Minnesota */
+#define XC_MGGA_C_M06_HF        234 /* Worker for M06-HF functional        */
+#define XC_MGGA_C_M06           235 /* Worker for M06 functional           */
+#define XC_MGGA_C_M06_2X        236 /* Worker for M06-2X functional        */
+#define XC_MGGA_C_DLDF           37 /* Dispersionless Density Functional   */
 
 static const FLOAT vsxc_dab[6]  = { 7.035010e-01,  7.694574e-03,  5.152765e-02,  3.394308e-05, -1.269420e-03,  1.296118e-03};
 static const FLOAT vsxc_dss[6]  = { 3.270912e-01, -3.228915e-02, -2.942406e-02,  2.134222e-03, -5.451559e-03,  1.577575e-02};
@@ -59,6 +60,10 @@ static const FLOAT m062x_css[5] = { 3.097855e-01, -5.528642e+00,  1.347420e+01,
 static const FLOAT m062x_dab[6] = { 1.166404e-01, -9.120847e-02, -6.726189e-02,  6.720580e-05,  8.448011e-04,  0.000000e+00};
 static const FLOAT m062x_dss[6] = { 6.902145e-01,  9.847204e-02,  2.214797e-01, -1.968264e-03, -6.775479e-03,  0.000000e+00};
 
+static const FLOAT dldf_cab[5]   = { 1.00000e0,  5.9515308, -11.1602877, 0.0, 0.0};
+static const FLOAT dldf_css[5]   = { 1.00000e0, -2.5960897,   2.2233793, 0.0, 0.0};
+
+
 typedef struct{
   const FLOAT *cab, *css, *dab, *dss;
   FLOAT alpha_ab, alpha_ss, gamma_ab, gamma_ss;
@@ -143,7 +148,14 @@ mgga_c_vsxc_init(XC(func_type) *p)
     params->dab = m062x_dab;
     params->alpha_ss = 0.00515088;
     params->dss = m062x_dss;
-    break;    
+    break;
+  case XC_MGGA_C_DLDF:
+    params->gamma_ab = 0.0031;
+    params->cab = dldf_cab;
+    params->gamma_ss = 0.06;
+    params->css = dldf_css;
+    params->dab = params->dss = NULL;
+    break;
   default:
     fprintf(stderr, "Internal error in mgga_c_vsxc\n");
     exit(1);
@@ -166,7 +178,7 @@ func(const XC(func_type) *pt, XC(mgga_work_c_t) *r)
   params = (mgga_c_m06l_params *)pt->params;
 
   /* first we get the parallel and perpendicular LDAS */
-  XC(lda_stoll) (pt->func_aux[0], r->dens, r->zeta, r->order, LDA);
+  XC(lda_stoll) (pt->func_aux[0], XC(lda_c_pw_func), r->dens, r->zeta, r->order, LDA);
 
   /* initialize to zero */
   r->f = 0.0;
@@ -251,12 +263,12 @@ func(const XC(func_type) *pt, XC(mgga_work_c_t) *r)
 
 #include "work_mgga_c.c"
 
-XC(func_info_type) XC(func_info_mgga_c_m05) = {
+const XC(func_info_type) XC(func_info_mgga_c_m05) = {
   XC_MGGA_C_M05,
   XC_CORRELATION,
-  "M05 functional of Minnesota",
+  "Worker for hyb_mgga_xc_m05",
   XC_FAMILY_MGGA,
-  "Y Zhao, NE Schultz, and DG Truhlar, J. Chem. Phys. 123, 161103 (2005)",
+  {&xc_ref_Zhao2005_161103, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_c_vsxc_init,
@@ -265,12 +277,12 @@ XC(func_info_type) XC(func_info_mgga_c_m05) = {
 };
 
 
-XC(func_info_type) XC(func_info_mgga_c_m05_2x) = {
+const XC(func_info_type) XC(func_info_mgga_c_m05_2x) = {
   XC_MGGA_C_M05_2X,
   XC_CORRELATION,
-  "M05-2X functional of Minnesota",
+  "Worker for hyb_mgga_xc_m05_2x",
   XC_FAMILY_MGGA,
-  "Y Zhao, NE Schultz, and DG Truhlar, J. Chem. Theory Comput. 2, 364 (2006)",
+  {&xc_ref_Zhao2006_364, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_c_vsxc_init,
@@ -283,7 +295,7 @@ const XC(func_info_type) XC(func_info_mgga_c_vsxc) = {
   XC_CORRELATION,
   "VSXC (correlation part)",
   XC_FAMILY_MGGA,
-  "T Van Voorhis and GE Scuseria, JCP 109, 400 (1998)",
+  {&xc_ref_VanVoorhis1998_400, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
   mgga_c_vsxc_init,
@@ -295,10 +307,9 @@ const XC(func_info_type) XC(func_info_mgga_c_vsxc) = {
 const XC(func_info_type) XC(func_info_mgga_c_m06_l) = {
   XC_MGGA_C_M06_L,
   XC_CORRELATION,
-  "M06-Local functional of Minnesota",
+  "Minnesota M06-L functional",
   XC_FAMILY_MGGA,
-  "Y Zhao and DG Truhlar, JCP 125, 194101 (2006)\n"
-  "Y Zhao and DG Truhlar, Theor. Chem. Account 120, 215 (2008)",
+  {&xc_ref_Zhao2006_194101, &xc_ref_Zhao2008_215, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
   mgga_c_vsxc_init,
@@ -310,9 +321,9 @@ const XC(func_info_type) XC(func_info_mgga_c_m06_l) = {
 const XC(func_info_type) XC(func_info_mgga_c_m06_hf) = {
   XC_MGGA_C_M06_HF,
   XC_CORRELATION,
-  "M06-HF functional of Minnesota",
+  "Worker for hyb_mgga_xc_m06_hf",
   XC_FAMILY_MGGA,
-  "Y Zhao and DG Truhlar, J. Phys. Chem. A 110, 13126 (2006)\n",
+  {&xc_ref_Zhao2006_13126, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
   mgga_c_vsxc_init,
@@ -324,9 +335,9 @@ const XC(func_info_type) XC(func_info_mgga_c_m06_hf) = {
 const XC(func_info_type) XC(func_info_mgga_c_m06) = {
   XC_MGGA_C_M06,
   XC_CORRELATION,
-  "M06 functional of Minnesota",
+  "Worker for hyb_mgga_xc_m06",
   XC_FAMILY_MGGA,
-  "Theor. Chem. Acc. 120, 215 (2008)\n",
+  {&xc_ref_Zhao2008_215, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
   mgga_c_vsxc_init,
@@ -338,9 +349,23 @@ const XC(func_info_type) XC(func_info_mgga_c_m06) = {
 const XC(func_info_type) XC(func_info_mgga_c_m06_2x) = {
   XC_MGGA_C_M06_2X,
   XC_CORRELATION,
-  "M06-2X functional of Minnesota",
+  "Worker for hyb_mgga_xc_m06_2x",
   XC_FAMILY_MGGA,
-  "Theor. Chem. Acc. 120, 215 (2008)\n",
+  {&xc_ref_Zhao2008_215, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
+  MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
+  mgga_c_vsxc_init,
+  NULL,
+  NULL, NULL,        /* this is not an LDA                   */
+  work_mgga_c,
+};
+
+const XC(func_info_type) XC(func_info_mgga_c_dldf) = {
+  XC_MGGA_C_DLDF,
+  XC_CORRELATION,
+  "Dispersionless Density Functional",
+  XC_FAMILY_MGGA,
+  {&xc_ref_Pernal2009_263201, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
   mgga_c_vsxc_init,
