@@ -265,7 +265,7 @@ const XC(func_info_type) XC(func_info_mgga_x_br89) = {
   XC_EXCHANGE,
   "Becke-Roussel 89",
   XC_FAMILY_MGGA,
-  "AD Becke and MR Roussel, Phys. Rev. A 39, 3761 (1989)",
+  {&xc_ref_Becke1989_3761, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
   NULL, NULL,
@@ -278,7 +278,7 @@ const XC(func_info_type) XC(func_info_mgga_x_bj06) = {
   XC_EXCHANGE,
   "Becke & Johnson 06",
   XC_FAMILY_MGGA,
-  "AD Becke and ER Johnson, J. Chem. Phys. 124, 221101 (2006)",
+  {&xc_ref_Becke2006_221101, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_VXC,
   1e-22, 1e-32, 1e-22, 1e-22,
   mgga_x_tb09_init,
@@ -292,7 +292,7 @@ const XC(func_info_type) XC(func_info_mgga_x_tb09) = {
   XC_EXCHANGE,
   "Tran & Blaha 09",
   XC_FAMILY_MGGA,
-  "F Tran and P Blaha, Phys. Rev. Lett. 102, 226401 (2009)",
+  {&xc_ref_Tran2009_226401, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_VXC,
   MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
   mgga_x_tb09_init,
@@ -306,7 +306,7 @@ const XC(func_info_type) XC(func_info_mgga_x_rpp09) = {
   XC_EXCHANGE,
   "Rasanen, Pittalis & Proetto 09",
   XC_FAMILY_MGGA,
-  "E Rasanen, S Pittalis & C Proetto, J. Chem. Phys. 132, 044112 (2010)",
+  {&xc_ref_Rasanen2010_044112, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_VXC,
   1e-22, 1e-22, 1e-22, 1e-22,
   mgga_x_tb09_init,
