@@ -22,9 +22,11 @@
 
 #include "util.h"
 
-#define XC_MGGA_X_M05          214 /* M05 functional of Minnesota */
-#define XC_MGGA_X_M05_2X       215 /* M05-2X functional of Minnesota */
-#define XC_MGGA_X_M06_2X       218 /* M06-2X functional of Minnesota */
+#define XC_MGGA_X_M05          214 /* Worker for M05 functional         */
+#define XC_MGGA_X_M05_2X       215 /* Worker for M05-2X functional      */
+#define XC_MGGA_X_M06_2X       218 /* Worker for M06-2X functional      */
+#define XC_HYB_MGGA_X_DLDF      36 /* Dispersionless Density Functional */
+
 
 static const FLOAT a_m05[12] = 
   {1.0, 0.08151, -0.43956, -3.22422, 2.01819, 8.79431, -0.00295,
@@ -38,9 +40,13 @@ static const FLOAT a_m06_2x[12] =
   {4.600000e-01, -2.206052e-01, -9.431788e-02,  2.164494e+00, -2.556466e+00, -1.422133e+01,
    1.555044e+01,  3.598078e+01, -2.722754e+01, -3.924093e+01,  1.522808e+01,  1.522227e+01};
 
+static const FLOAT a_dldf[5] =
+  {1.0, -0.1637571, -0.1880028, -0.4490609, -0.0082359};
+
 typedef struct{
   int n;
   const FLOAT *a;
+  FLOAT csi_HF;
 } mgga_x_m05_params;
 
 
@@ -65,14 +71,26 @@ mgga_x_m05_init(XC(func_type) *p)
   case XC_MGGA_X_M05: 
     params->n = 12;
     params->a = a_m05;
+    params->csi_HF = 1.0;
     break;
   case XC_MGGA_X_M05_2X:
     params->n = 12;
     params->a = a_m05_2x;
+    params->csi_HF = 1.0;
     break;
   case XC_MGGA_X_M06_2X:
     params->n = 12;
     params->a = a_m06_2x;
+    params->csi_HF = 1.0;
+    break;
+  case XC_HYB_MGGA_X_DLDF:
+    params->n = 5;
+    params->a = a_dldf;
+
+    XC(gga_x_pbe_set_params)(p->func_aux[0], 4.8827323, 0.3511128);
+
+    p->cam_alpha = 0.6144129;
+    params->csi_HF = 1.0 - p->cam_alpha;
     break;
   default:
     fprintf(stderr, "Internal error in mgga_x_m05\n");
@@ -96,12 +114,12 @@ func(const XC(func_type) *pt, XC(mgga_work_x_t) *r)
   
   XC(mgga_series_w)(r->order, params->n, params->a, r->t, &fw, &dfwdt);
 
-  r->f = e_f*fw;
+  r->f = params->csi_HF*e_f*fw;
 
   if(r->order < 1) return;
 
-  r->dfdx = e_dfdx*fw;
-  r->dfdt = e_f*dfwdt;
+  r->dfdx = params->csi_HF*e_dfdx*fw;
+  r->dfdt = params->csi_HF*e_f*dfwdt;
   r->dfdu = 0.0;
 
   if(r->order < 2) return;
@@ -112,12 +130,12 @@ func(const XC(func_type) *pt, XC(mgga_work_x_t) *r)
 #include "work_mgga_x.c"
 
 
-XC(func_info_type) XC(func_info_mgga_x_m05) = {
+const XC(func_info_type) XC(func_info_mgga_x_m05) = {
   XC_MGGA_X_M05,
   XC_EXCHANGE,
-  "M05 functional of Minnesota",
+  "Worker for hyb_mgga_xc_m05",
   XC_FAMILY_MGGA,
-  "Y Zhao, NE Schultz, and DG Truhlar, J. Chem. Phys. 123, 161103 (2005)",
+  {&xc_ref_Zhao2005_161103, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_x_m05_init,
@@ -126,12 +144,12 @@ XC(func_info_type) XC(func_info_mgga_x_m05) = {
 };
 
 
-XC(func_info_type) XC(func_info_mgga_x_m05_2x) = {
+const XC(func_info_type) XC(func_info_mgga_x_m05_2x) = {
   XC_MGGA_X_M05_2X,
   XC_EXCHANGE,
-  "M05-2X functional of Minnesota",
+  "Worker for hyb_mgga_xc_m05_2x",
   XC_FAMILY_MGGA,
-  "Y Zhao, NE Schultz, and DG Truhlar, J. Chem. Theory Comput. 2, 364 (2006)",
+  {&xc_ref_Zhao2006_364, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_x_m05_init,
@@ -142,9 +160,23 @@ XC(func_info_type) XC(func_info_mgga_x_m05_2x) = {
 const XC(func_info_type) XC(func_info_mgga_x_m06_2x) = {
   XC_MGGA_X_M06_2X,
   XC_EXCHANGE,
-  "M06-2X functional of Minnesota",
+  "Worker for hyb_mgga_m06_2x",
   XC_FAMILY_MGGA,
-  "Y Zhao and DG Truhlar, Theor. Chem. Acc. 120, 215 (2008)",
+  {&xc_ref_Zhao2008_215, NULL, NULL, NULL, NULL},
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
+  MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
+  mgga_x_m05_init,
+  NULL,
+  NULL, NULL,        /* this is not an LDA                   */
+  work_mgga_x,
+};
+
+const XC(func_info_type) XC(func_info_hyb_mgga_x_dldf) = {
+  XC_HYB_MGGA_X_DLDF,
+  XC_EXCHANGE,
+  "Dispersionless Density Functional",
+  XC_FAMILY_HYB_MGGA,
+  {&xc_ref_Pernal2009_263201, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
   mgga_x_m05_init,
