@@ -23,8 +23,8 @@
 #include "util.h"
 
 #define XC_MGGA_X_M06_L         203 /* M06-Local functional of Minnesota */
-#define XC_MGGA_X_M06_HF        216 /* M06-HF functional of Minnesota */
-#define XC_MGGA_X_M06           217 /* M06 functional of Minnesota */
+#define XC_MGGA_X_M06_HF        216 /* Worker for M06-HF functional      */
+#define XC_MGGA_X_M06           217 /* Worker for M06 functional         */
 
 static const FLOAT a_m06l[12] = {
   0.3987756, 0.2548219, 0.3923994, -2.103655, -6.302147, 10.97615,
@@ -144,10 +144,9 @@ func(const XC(func_type) *pt, XC(mgga_work_x_t) *r)
 const XC(func_info_type) XC(func_info_mgga_x_m06_l) = {
   XC_MGGA_X_M06_L,
   XC_EXCHANGE,
-  "M06-Local functional of Minnesota",
+  "Minnesota M06-L functional",
   XC_FAMILY_MGGA,
-  "Y Zhao and DG Truhlar, JCP 125, 194101 (2006)\n"
-  "Y Zhao and DG Truhlar, Theor. Chem. Account 120, 215 (2008)",
+  {&xc_ref_Zhao2006_194101, &xc_ref_Zhao2008_215, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
   mgga_x_m06l_init,
@@ -159,9 +158,9 @@ const XC(func_info_type) XC(func_info_mgga_x_m06_l) = {
 const XC(func_info_type) XC(func_info_mgga_x_m06_hf) = {
   XC_MGGA_X_M06_HF,
   XC_EXCHANGE,
-  "M06-HF functional of Minnesota",
+  "Worker for hyb_mgga_xc_m06_hf",
   XC_FAMILY_MGGA,
-  "Y Zhao and DG Truhlar, J. Phys. Chem. A 110, 13126 (2006)",
+  {&xc_ref_Zhao2006_13126, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
   mgga_x_m06l_init,
@@ -173,9 +172,9 @@ const XC(func_info_type) XC(func_info_mgga_x_m06_hf) = {
 const XC(func_info_type) XC(func_info_mgga_x_m06) = {
   XC_MGGA_X_M06,
   XC_EXCHANGE,
-  "M06 functional of Minnesota",
+  "Worker for hyb_mgga_xc_m06",
   XC_FAMILY_MGGA,
-  "Y Zhao and DG Truhlar, Theor. Chem. Acc. 120, 215 (2008)",
+  {&xc_ref_Zhao2008_215, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
   MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
   mgga_x_m06l_init,
