@@ -25,7 +25,7 @@
 #define XC_MGGA_X_MS0          221 /* MS exchange of Sun, Xiao, and Ruzsinszky */
 #define XC_MGGA_X_MS1          222 /* MS1 exchange of Sun, et al */
 #define XC_MGGA_X_MS2          223 /* MS2 exchange of Sun, et al */
-#define XC_MGGA_X_MS2H         224 /* MS2 hybrid exchange of Sun, et al */
+#define XC_HYB_MGGA_X_MS2H     224 /* MS2 hybrid exchange of Sun, et al */
 
 typedef struct{
   FLOAT kappa, c, b;
@@ -40,7 +40,6 @@ mgga_x_ms_init(XC(func_type) *p)
   p->params = malloc(sizeof(mgga_x_ms_params));
   params = (mgga_x_ms_params *)p->params;
 
-  /* value of beta in standard Becke 88 functional */
   switch(p->info->number){
   case XC_MGGA_X_MS0:
     params->kappa = 0.29;
@@ -57,19 +56,12 @@ mgga_x_ms_init(XC(func_type) *p)
     params->c     = 0.14601;
     params->b     = 4.0;
     break;
-  case XC_MGGA_X_MS2H:
-    p->cam_alpha  = 0.09;
-    params->kappa = 0.504;
-    params->c     = 0.14601;
-    params->b     = 4.0;
-    break;
   default:
     fprintf(stderr, "Internal error in mgga_x_ms\n");
     exit(1);
   }
 }
 
-
 static void 
 func_fa(FLOAT b, int order, FLOAT a, 
 	FLOAT *f, FLOAT *dfda, FLOAT *d2fda2)
@@ -179,12 +171,12 @@ func(const XC(func_type) *pt, XC(mgga_work_x_t) *r)
 #include "work_mgga_x.c"
 
 
-XC(func_info_type) XC(func_info_mgga_x_ms0) = {
+const XC(func_info_type) XC(func_info_mgga_x_ms0) = {
   XC_MGGA_X_MS0,
   XC_EXCHANGE,
   "MS exchange of Sun, Xiao, and Ruzsinszky",
   XC_FAMILY_MGGA,
-  "J Sun, B Xiao, and A Ruzsinszky, J. Chem. Phys. 137, 051101 (2012)",
+  {&xc_ref_Sun2012_051101, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_x_ms_init,
@@ -192,12 +184,12 @@ XC(func_info_type) XC(func_info_mgga_x_ms0) = {
   work_mgga_x,
 };
 
-XC(func_info_type) XC(func_info_mgga_x_ms1) = {
+const XC(func_info_type) XC(func_info_mgga_x_ms1) = {
   XC_MGGA_X_MS1,
   XC_EXCHANGE,
   "MS1 exchange of Sun, et al",
   XC_FAMILY_MGGA,
-  "J Sun, R Haunschild, B Xiao, IW Bulik, GE Scuseria, JP Perdew, J. Chem. Phys. 138, 044113 (2013)",
+  {&xc_ref_Sun2013_044113, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_x_ms_init,
@@ -205,12 +197,12 @@ XC(func_info_type) XC(func_info_mgga_x_ms1) = {
   work_mgga_x,
 };
 
-XC(func_info_type) XC(func_info_mgga_x_ms2) = {
+const XC(func_info_type) XC(func_info_mgga_x_ms2) = {
   XC_MGGA_X_MS2,
   XC_EXCHANGE,
   "MS2 exchange of Sun, et al",
   XC_FAMILY_MGGA,
-  "J Sun, R Haunschild, B Xiao, IW Bulik, GE Scuseria, JP Perdew, J. Chem. Phys. 138, 044113 (2013)",
+  {&xc_ref_Sun2013_044113, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_x_ms_init,
@@ -218,15 +210,33 @@ XC(func_info_type) XC(func_info_mgga_x_ms2) = {
   work_mgga_x,
 };
 
-XC(func_info_type) XC(func_info_mgga_x_ms2h) = {
-  XC_MGGA_X_MS2H,
+static void
+hyb_mgga_x_ms2h_init(XC(func_type) *p)
+{
+  static int   funcs_id  [1] = {XC_MGGA_X_MS2};
+  static FLOAT funcs_coef[1] = {0.91};
+
+  XC(mix_init)(p, 1, funcs_id, funcs_coef);
+  p->cam_alpha = 0.09;
+}
+
+void
+XC(hyb_mgga_x_ms2h_set_params)(XC(func_type) *p, FLOAT alpha)
+{
+  assert(alpha>=0 && alpha<=1.0);
+
+  p->cam_alpha   = alpha;
+  p->mix_coef[0] = 1.0 - alpha;
+}
+
+const XC(func_info_type) XC(func_info_hyb_mgga_x_ms2h) = {
+  XC_HYB_MGGA_X_MS2H,
   XC_EXCHANGE,
   "MS2 hybrid exchange of Sun, et al",
-  XC_FAMILY_MGGA,
-  "J Sun, R Haunschild, B Xiao, IW Bulik, GE Scuseria, JP Perdew, J. Chem. Phys. 138, 044113 (2013)",
+  XC_FAMILY_HYB_MGGA,
+  {&xc_ref_Sun2013_044113, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 1e-32, 1e-32,
-  mgga_x_ms_init,
-  NULL, NULL, NULL,
-  work_mgga_x,
+  hyb_mgga_x_ms2h_init,
+  NULL, NULL, NULL, NULL
 };
