@@ -48,7 +48,6 @@ mgga_x_tpss_init(XC(func_type) *p)
   p->params = malloc(sizeof(mgga_x_tpss_params));
   params = (mgga_x_tpss_params *)p->params;
 
-  /* value of beta in standard Becke 88 functional */
   switch(p->info->number){
   case XC_MGGA_X_TPSS:
     params->func = p->func = 0;
@@ -56,7 +55,7 @@ mgga_x_tpss_init(XC(func_type) *p)
     break;
   case XC_MGGA_X_MODTPSS:
     params->func = p->func = 0; /* this has exactly the same form as TPSS */
-    XC(mgga_x_tpss_set_params)(p, 0.40, 1.39660, 1.38, 0.804, 0.250);
+    XC(mgga_x_tpss_set_params)(p, 0.40, 1.38496, 1.37, 0.804, 0.252);
     break;
   case XC_MGGA_X_REVTPSS:
     params->func = p->func = 1;
@@ -307,13 +306,12 @@ func(const XC(func_type) *pt, XC(mgga_work_x_t) *r)
 #include "work_mgga_x.c"
 
 
-XC(func_info_type) XC(func_info_mgga_x_tpss) = {
+const XC(func_info_type) XC(func_info_mgga_x_tpss) = {
   XC_MGGA_X_TPSS,
   XC_EXCHANGE,
   "Tao, Perdew, Staroverov & Scuseria",
   XC_FAMILY_MGGA,
-  "J Tao, JP Perdew, VN Staroverov, and G Scuseria, Phys. Rev. Lett. 91, 146401 (2003)\n"
-  "JP Perdew, J Tao, VN Staroverov, and G Scuseria, J. Chem. Phys. 120, 6898 (2004)",
+  {&xc_ref_Tao2003_146401, &xc_ref_Perdew2004_6898, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_x_tpss_init,
@@ -321,12 +319,12 @@ XC(func_info_type) XC(func_info_mgga_x_tpss) = {
   work_mgga_x,
 };
 
-XC(func_info_type) XC(func_info_mgga_x_modtpss) = {
+const XC(func_info_type) XC(func_info_mgga_x_modtpss) = {
   XC_MGGA_X_MODTPSS,
   XC_EXCHANGE,
   "Modified Tao, Perdew, Staroverov & Scuseria",
   XC_FAMILY_MGGA,
-  "JP Perdew, A Ruzsinszky, J Tao, GI Csonka, and GE Scuseria, Phys. Rev. A 76, 042506 (2007)",
+  {&xc_ref_Perdew2007_042506, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_x_tpss_init,
@@ -334,13 +332,12 @@ XC(func_info_type) XC(func_info_mgga_x_modtpss) = {
   work_mgga_x,
 };
 
-XC(func_info_type) XC(func_info_mgga_x_revtpss) = {
+const XC(func_info_type) XC(func_info_mgga_x_revtpss) = {
   XC_MGGA_X_REVTPSS,
   XC_EXCHANGE,
   "revised Tao, Perdew, Staroverov & Scuseria",
   XC_FAMILY_MGGA,
-  "JP Perdew, A Ruzsinszky, GI Csonka, LA Constantin, and J Sun, Phys. Rev. Lett. 103, 026403 (2009)\n"
-  "JP Perdew, A Ruzsinszky, GI Csonka, LA Constantin, and J Sun, Phys. Rev. Lett. 106, 179902(E) (2011)",
+  {&xc_ref_Perdew2009_026403, &xc_ref_Perdew2009_026403_err, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_x_tpss_init,
@@ -348,12 +345,12 @@ XC(func_info_type) XC(func_info_mgga_x_revtpss) = {
   work_mgga_x,
 };
 
-XC(func_info_type) XC(func_info_mgga_x_bloc) = {
+const XC(func_info_type) XC(func_info_mgga_x_bloc) = {
   XC_MGGA_X_BLOC,
   XC_EXCHANGE,
   "functional with balanced localization",
   XC_FAMILY_MGGA,
-  "LA Constantin, E Fabiano, F Della Sala, J. Chem. Theory Comput. 9, 2256 (2013)",
+  {&xc_ref_Constantin2013_2256, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
   1e-32, 1e-32, 1e-32, 1e-32,
   mgga_x_tpss_init,
