@@ -95,6 +95,8 @@ XC(mix_init)(XC(func_type) *p, int n_funcs, const int *funcs_id, const FLOAT *mi
   p->cam_omega=0.0;
   p->cam_alpha=0.0;
   p->cam_beta=0.0;
+  p->nlc_b=0.0;
+  p->nlc_C=0.0;
 }
 
 xc_gga_enhancement_t
@@ -128,10 +130,9 @@ XC(get_gga_enhancement_factor)(int func_id)
     return XC(gga_x_htbs_enhance);
 
   case XC_GGA_X_B86:
-    return XC(gga_x_b86_enhance);
-
   case XC_GGA_X_B86_MGC:
-    return XC(gga_x_b86_mgc_enhance);
+  case XC_GGA_X_B86_R:
+    return XC(gga_x_b86_enhance);
 
   case XC_GGA_X_B88:
   case XC_GGA_X_OPTB88_VDW:
