@@ -27,6 +27,9 @@
 /* xc_config.h needs to be included to use FLOAT and related macros*/
 #include "xc_config.h"
 
+/* we include the references also */
+#include "references.h"
+
 /* If strict ANSI, then some useful macros are not defined */
 #if defined(__STRICT_ANSI__)
 # define M_E            2.7182818284590452354   /* e */
@@ -151,11 +154,19 @@ void XC(lda_kxc_fd)(const XC(func_type) *p, int np, const FLOAT *rho, FLOAT *kxc
 #define XC_RSF_ERF_GAU  1
 #define XC_RSF_YUKAWA   2
 
+typedef void XC(lda_func_type) (const XC(func_type) *p, XC(lda_work_t) *r);
+
+void XC(lda_x_attenuation_function_erf)(int order, FLOAT aa, FLOAT *f, FLOAT *df, FLOAT *d2f, FLOAT *d3f);
+void XC(lda_x_attenuation_function_erf_gau)(int order, FLOAT aa, FLOAT *f, FLOAT *df, FLOAT *d2f, FLOAT *d3f);
+void XC(lda_x_attenuation_function_yukawa)(int order, FLOAT aa, FLOAT *f, FLOAT *df, FLOAT *d2f, FLOAT *d3f);
 void XC(lda_x_attenuation_function)(int interaction, int order, FLOAT aa, FLOAT *f, FLOAT *df, FLOAT *d2f, FLOAT *d3f);
-void XC(lda_stoll)(const XC(func_type) *pw, FLOAT dens, FLOAT zeta, int order, XC(lda_work_t) res[3]);
+void XC(lda_stoll)(const XC(func_type) *pw, XC(lda_func_type) lda_func, 
+		   FLOAT dens, FLOAT zeta, int order, XC(lda_work_t) res[3]);
 
 /* direct access to the internal functions */
+void XC(lda_x_func)     (const XC(func_type) *p, XC(lda_work_t) *r);
 void XC(lda_c_hl_func)  (const XC(func_type) *p, XC(lda_work_t) *r);
+void XC(lda_c_vwn_func) (const XC(func_type) *p, XC(lda_work_t) *r);
 void XC(lda_c_pw_func)  (const XC(func_type) *p, XC(lda_work_t) *r);
 void XC(lda_c_pz_func)  (const XC(func_type) *p, XC(lda_work_t) *r);
 void XC(lda_c_rc04_func)(const XC(func_type) *p, XC(lda_work_t) *r);
@@ -175,7 +186,6 @@ void XC(gga_x_pw91_enhance) (const XC(func_type) *p, int order, FLOAT x, FLOAT *
 void XC(gga_x_rpbe_enhance) (const XC(func_type) *p, int order, FLOAT x, FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3);
 void XC(gga_x_htbs_enhance) (const XC(func_type) *p, int order, FLOAT x, FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3);
 void XC(gga_x_b86_enhance)  (const XC(func_type) *p, int order, FLOAT x, FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3);
-void XC(gga_x_b86_mgc_enhance)(const XC(func_type) *p, int order, FLOAT x, FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3);
 void XC(gga_x_b88_enhance)  (const XC(func_type) *p, int order, FLOAT x, FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3);
 void XC(gga_x_g96_enhance)  (const XC(func_type) *p, int order, FLOAT x, FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3);
 void XC(gga_x_pw86_enhance) (const XC(func_type) *p, int order, FLOAT x, FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3);
@@ -254,7 +264,9 @@ void XC(pbe_c_stoll) (const XC(func_type) *pbe, int get_max, const XC(mgga_work_
 void XC(mgga_series_w)(int order, int n, const FLOAT *a, FLOAT t, FLOAT *fw, FLOAT *dfwdt);
 void XC(mgga_b97_func_g)(const FLOAT *cc, FLOAT gamma, FLOAT s, int order, FLOAT *g, FLOAT *dgds, FLOAT *d2gds2);
 void XC(mgga_x_gvt4_func)(int order, FLOAT x, FLOAT z, FLOAT alpha, const FLOAT *d, FLOAT *h, FLOAT *dhdx, FLOAT *dhdz);
-
+FLOAT XC(mgga_x_scan_exp1)(FLOAT c1x, FLOAT a);
+FLOAT XC(mgga_x_scan_exp2)(FLOAT c2x, FLOAT a);
+			 
 /* useful MACROS */
 #define DFRACTION(num, dnum, den, dden) \
   (((dnum)*(den) - (num)*(dden))/((den)*(den)))
