@@ -17,15 +17,22 @@
 */
 
 #include <stdio.h>
+#include <string.h>
 
 #include "xc.h"
 #include "config.h"
 
-void XC(version)(int *major, int *minor) {
-  const char *version_string = PACKAGE_VERSION;
+const char * libxc_version = PACKAGE_VERSION;
+
+void XC(version)(int *major, int *minor, int *micro) {
 
   *major = -1;
   *minor = -1;
-  sscanf(version_string,"%d.%d",major,minor);
+  *micro = -1;
+  sscanf(libxc_version,"%d.%d.%d",major,minor,micro);
 
 }
+
+const char *XC(version_string)() {
+  return libxc_version;
+}
