@@ -29,9 +29,8 @@
 #define XC_DIMENSIONS 3
 #endif
 
-/**
- * @param[in,out] func_type: pointer to pspdata structure to be initialized
- */
+#include <string.h>
+
 /**
  * @param[in,out] func_type: pointer to pspdata structure to be initialized
  */
@@ -52,6 +51,9 @@ work_lda(const XC(func_type) *p, int np, const FLOAT *rho,
   const FLOAT cnst_rs = RS_FACTOR;
 # endif
 
+  /* Initialize memory */
+  memset(&r, 0, sizeof(r));
+
   r.order = -1;
   if(zk     != NULL) r.order = 0;
   if(vrho   != NULL) r.order = 1;
