@@ -46,38 +46,51 @@ extern "C" {
 #define XC_FAMILY_HYB_GGA      32
 #define XC_FAMILY_HYB_MGGA     64
 
-/* flags that can be used in info.flags */
-#define XC_FLAGS_HAVE_EXC         (1 <<  0) /*    1 */
-#define XC_FLAGS_HAVE_VXC         (1 <<  1) /*    2 */
-#define XC_FLAGS_HAVE_FXC         (1 <<  2) /*    4 */
-#define XC_FLAGS_HAVE_KXC         (1 <<  3) /*    8 */
-#define XC_FLAGS_HAVE_LXC         (1 <<  4) /*   16 */
-#define XC_FLAGS_1D               (1 <<  5) /*   32 */
-#define XC_FLAGS_2D               (1 <<  6) /*   64 */
-#define XC_FLAGS_3D               (1 <<  7) /*  128 */
-#define XC_FLAGS_HYB_CAM          (1 <<  8) /*  256 */
-#define XC_FLAGS_STABLE           (1 <<  9) /*  512 */
-#define XC_FLAGS_DEVELOPMENT      (1 << 10) /* 1024 */
+/* flags that can be used in info.flags. Don't reorder these since it
+   will break the ABI of the library. */
+#define XC_FLAGS_HAVE_EXC         (1 <<  0) /*     1 */
+#define XC_FLAGS_HAVE_VXC         (1 <<  1) /*     2 */
+#define XC_FLAGS_HAVE_FXC         (1 <<  2) /*     4 */
+#define XC_FLAGS_HAVE_KXC         (1 <<  3) /*     8 */
+#define XC_FLAGS_HAVE_LXC         (1 <<  4) /*    16 */
+#define XC_FLAGS_1D               (1 <<  5) /*    32 */
+#define XC_FLAGS_2D               (1 <<  6) /*    64 */
+#define XC_FLAGS_3D               (1 <<  7) /*   128 */
+#define XC_FLAGS_HYB_CAM          (1 <<  8) /*   256 */
+#define XC_FLAGS_HYB_CAMY         (1 <<  9) /*   512 */
+#define XC_FLAGS_VV10             (1 << 10) /*  1024 */
+#define XC_FLAGS_HYB_LC           (1 << 11) /*  2048 */
+#define XC_FLAGS_HYB_LCY          (1 << 12) /*  4096 */
+#define XC_FLAGS_STABLE           (1 << 13) /*  8192 */ 
+#define XC_FLAGS_DEVELOPMENT      (1 << 14) /* 16384 */
 
 #define XC_TAU_EXPLICIT         0
 #define XC_TAU_EXPANSION        1
 
-/* These are old names keep for compatibility, and that should disappear soon */
+/* These are old names kept for compatibility, and that should disappear soon */
+#define XC_GGA_C_VPBE          83
 #define XC_GGA_XC_LB          160
 #define XC_GGA_K_ABSR1        506
 #define XC_GGA_K_ABSR2        507
+#define XC_MGGA_X_MN12_SX     248
 
-void XC(version)(int *major, int *minor);
-
+void XC(version)(int *major, int *minor, int *micro);
+const char *XC(version_string)();
+    
 struct XC(func_type);
 
+typedef struct{
+  char *ref, *doi, *bibtex;
+} func_reference_type;
+
+
 typedef struct{
   int   number;   /* identifier number */
   int   kind;     /* XC_EXCHANGE, XC_CORRELATION, XC_EXCHANGE_CORRELATION, XC_KINETIC */
 
   char *name;     /* name of the functional, e.g. "PBE" */
   int   family;   /* type of the functional, e.g. XC_FAMILY_GGA */
-  char *refs;     /* references                       */
+  func_reference_type *refs[5];  /* index of the references */
 
   int   flags;    /* see above for a list of possible flags */
 
@@ -104,6 +117,12 @@ typedef struct{
 	       FLOAT *v2sigmatau, FLOAT *v2sigmalapl, FLOAT *v2taulapl);
 } XC(func_info_type);
 
+int XC(func_info_get_number)(const XC(func_info_type) *info);
+int XC(func_info_get_kind)(const XC(func_info_type) *info);
+char const *XC(func_info_get_name)(const XC(func_info_type) *info);
+int XC(func_info_get_family)(const XC(func_info_type) *info);
+int XC(func_info_get_flags)(const XC(func_info_type) *info);
+char const *XC(func_info_get_ref)(const XC(func_info_type) *info, int number);
 
 struct XC(func_type){
   const XC(func_info_type) *info;       /* all the information concerning this functional */
@@ -113,9 +132,12 @@ struct XC(func_type){
   struct XC(func_type) **func_aux;      /* most GGAs are based on a LDA or other GGAs  */
   FLOAT *mix_coef;                      /* coefficients for the mixing */
 
-  FLOAT cam_omega;                      /* range separation parameter for hybrids */
-  FLOAT cam_alpha;                      /* the Hartree-Fock mixing parameter for the hybrids */
-  FLOAT cam_beta;                       /* idem, but for the screened hybrid */
+  FLOAT cam_omega;                      /* range-separation parameter for range-separated hybrids */
+  FLOAT cam_alpha;                      /* fraction of Hartree-Fock exchange for normal or range separated hybrids */
+  FLOAT cam_beta;                       /* fraction of short-range exchange for range-separated hybrids */
+
+  FLOAT nlc_b;                          /* Non-local correlation, b parameter */
+  FLOAT nlc_C;                          /* Non-local correlation, C parameter */
 
   int func;                             /* Shortcut in case of several functionals sharing the same interface */
   int n_rho, n_sigma, n_tau, n_lapl;    /* spin dimensions of the arrays */
@@ -138,9 +160,12 @@ typedef struct XC(func_type) XC(func_type);
 int   XC(functional_get_number)(const char *name);
 char *XC(functional_get_name)(int number);
 int   XC(family_from_id)(int id, int *family, int *number);
+XC(func_type) *XC(func_alloc)();
 int   XC(func_init)(XC(func_type) *p, int functional, int nspin);
 void  XC(func_end)(XC(func_type) *p);
-
+void  XC(func_free)(XC(func_type) *p);
+const XC(func_info_type) *XC(func_get_info)(const XC(func_type) *p);
+    
 #include "xc_funcs.h"
 
 int  XC(lda_init)(XC(func_type) *p, const XC(func_info_type) *info, int nspin);
@@ -159,6 +184,7 @@ void XC(lda_c_1d_csc_set_params) (XC(func_type) *p, int interaction, FLOAT bb);
 void XC(lda_c_xalpha_set_params) (XC(func_type) *p, FLOAT alpha);
 void XC(lda_c_2d_prm_set_params) (XC(func_type) *p, FLOAT N);
 void XC(lda_c_vwn_set_params)    (XC(func_type) *p, int spin_interpolation);
+void XC(lda_xc_ksdt_set_params)  (XC(func_type) *p, FLOAT T);
 
 
 int  XC(gga_init)(XC(func_type) *p, const XC(func_info_type) *info, int nspin);
@@ -181,6 +207,7 @@ void XC(gga_kxc)(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *
 void XC(gga_lb_modified)  (const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma, 
 			   FLOAT r, FLOAT *vrho);
 
+void XC(gga_x_b86_set_params)     (XC(func_type) *p, FLOAT beta, FLOAT gamma, FLOAT omega);
 void XC(gga_x_b88_set_params)     (XC(func_type) *p, FLOAT beta, FLOAT gamma);
 void XC(gga_x_pbe_set_params)     (XC(func_type) *p, FLOAT kappa, FLOAT mu);
 void XC(gga_c_pbe_set_params)     (XC(func_type) *p, FLOAT beta);
@@ -198,11 +225,13 @@ void XC(gga_x_ityh_set_params)    (XC(func_type) *p, int func_id, FLOAT omega);
 void XC(gga_x_sfat_set_params)    (XC(func_type) *p, int func_id, FLOAT omega);
 void XC(gga_x_ssb_sw_set_params)  (XC(func_type) *p, FLOAT A, FLOAT B, FLOAT C, FLOAT D, FLOAT E);
 void XC(gga_x_kt_set_params)      (XC(func_type) *p, FLOAT gamma, FLOAT delta);
+void XC(gga_x_lambda_set_params)  (XC(func_type) *p, FLOAT N);
 
 FLOAT XC(gga_ak13_get_asymptotic) (FLOAT homo);
 
 FLOAT XC(hyb_exx_coef)(const XC(func_type) *p);
 void  XC(hyb_cam_coef)(const XC(func_type) *p, FLOAT *omega, FLOAT *alpha, FLOAT *beta);
+void  XC(nlc_coef)(const XC(func_type) *p, FLOAT *nlc_b, FLOAT *nlc_C);
 
 void XC(hyb_gga_xc_hse_set_params) (XC(func_type) *p, FLOAT alpha, FLOAT omega);
 void XC(hyb_gga_xc_pbeh_set_params)(XC(func_type) *p, FLOAT alpha);
@@ -252,4 +281,3 @@ void XC(mix_func)
 #endif
 
 #endif
-
