@@ -33,11 +33,19 @@
 
 /* version */
 void XC_FC_FUNC(f90_version, F90_VERSION)
-     (int *major, int *minor)
+     (int *major, int *minor, int *micro)
 {
-  XC(version)(major, minor);
+  XC(version)(major, minor, micro);
 }
 
+void XC_FC_FUNC(f90_version_string, F90_VERSIN_STRING)
+     (STR_F_TYPE version_string STR_ARG1)
+{
+  const char *version;
+
+  version = XC(version_string)();
+  TO_F_STR1(version, version_string);
+}
 
 /* info */
 CC_FORTRAN_INT XC_FC_FUNC(f90_info_number, F90_INFO_NUMBER)
@@ -76,24 +84,18 @@ CC_FORTRAN_INT  XC_FC_FUNC(f90_info_flags, F90_INFO_FLAGS)
 
 
 void XC_FC_FUNC(f90_info_refs, F90_INFO_REFS)
-     (void **info, CC_FORTRAN_INT *number, char **s, STR_F_TYPE ref_f STR_ARG1)
+     (void **info, CC_FORTRAN_INT *number, STR_F_TYPE ref_f STR_ARG1)
 {
-  char *c, ref[256]; /* hopefully no ref is longer than 256 characters ;) */
   XC(func_info_type) *func_p = (XC(func_info_type) *)(*info);
 
-  if(*number == 0) *s = func_p->refs;
+  assert(*number >=0 && *number < 5);
 
-  if(*s == NULL || **s == '\0'){
+  if(func_p->refs[*number] == NULL){
     *number = -1;
     return;
   }
 
-  for(c=ref; **s!='\0' && **s!='\n'; (*s)++, c++)
-    *c = **s;
-  *c = '\0';
-  if(**s=='\n') (*s)++;
-
-  TO_F_STR1(ref, ref_f);
+  TO_F_STR1(func_p->refs[*number]->ref, ref_f);
 
   (*number)++;
   fflush(stdout);
@@ -168,7 +170,6 @@ void XC_FC_FUNC(f90_lda, F90_LDA)
   XC(lda)((XC(func_type) *)(*p), *np, rho, zk, vrho, v2rho2, v3rho3);
 }
 
-
 void XC_FC_FUNC(f90_lda_exc, F90_LDA_EXC)
      (void **p, CC_FORTRAN_INT *np, FLOAT *rho,
       FLOAT *zk)
@@ -176,7 +177,6 @@ void XC_FC_FUNC(f90_lda_exc, F90_LDA_EXC)
   XC(lda)((XC(func_type) *)(*p), *np, rho, zk, NULL, NULL, NULL);
 }
 
-
 void XC_FC_FUNC(f90_lda_exc_vxc, F90_LDA_EXC_VXC)
      (void **p, CC_FORTRAN_INT *np, FLOAT *rho, 
       FLOAT *zk, FLOAT *vrho)
@@ -184,7 +184,6 @@ void XC_FC_FUNC(f90_lda_exc_vxc, F90_LDA_EXC_VXC)
   XC(lda)((XC(func_type) *)(*p), *np, rho, zk, vrho, NULL, NULL);
 }
 
-
 void XC_FC_FUNC(f90_lda_vxc, F90_LDA_VXC)
      (void **p, CC_FORTRAN_INT *np, FLOAT *rho, 
       FLOAT *vrho)
@@ -192,6 +191,12 @@ void XC_FC_FUNC(f90_lda_vxc, F90_LDA_VXC)
   XC(lda)((XC(func_type) *)(*p), *np, rho, NULL, vrho, NULL, NULL);
 }
 
+void XC_FC_FUNC(f90_lda_vxc_fxc, F90_LDA_VXC_FXC)
+     (void **p, CC_FORTRAN_INT *np, FLOAT *rho,
+      FLOAT *vrho, FLOAT *v2rho2)
+{
+  XC(lda)((XC(func_type) *)(*p), *np, rho, NULL, vrho, v2rho2, NULL);
+}
 
 void XC_FC_FUNC(f90_lda_fxc, F90_LDA_FXC)
      (void **p, CC_FORTRAN_INT *np, FLOAT *rho,
@@ -200,7 +205,6 @@ void XC_FC_FUNC(f90_lda_fxc, F90_LDA_FXC)
   XC(lda)((XC(func_type) *)(*p), *np, rho, NULL, NULL, v2rho2, NULL);
 }
 
-
 void XC_FC_FUNC(f90_lda_kxc, F90_LDA_KXC)
      (void **p, CC_FORTRAN_INT *np, FLOAT *rho,
       FLOAT *v3rho3)
@@ -246,6 +250,13 @@ void XC_FC_FUNC(f90_lda_c_2d_prm_set_par, F90_LDA_C_2D_PRM_SET_PAR)
   XC(lda_c_2d_prm_set_params)((XC(func_type) *)(*p), *N);
 }
 
+/* Parameter of KSDT (temperature in Kelvin) */
+void XC_FC_FUNC(f90_lda_xc_ksdt_set_par, F90_LDA_XC_KSDT_SET_PAR)
+  (void **p, FLOAT *T)
+{
+  XC(lda_xc_ksdt_set_params)((XC(func_type) *)(*p), *T);
+}
+
 
 /* GGAs */
 
@@ -283,6 +294,15 @@ void XC_FC_FUNC(f90_gga_vxc, F90_GGA_VXC)
 	  NULL, NULL, NULL, NULL, NULL, NULL, NULL);
 }
 
+void XC_FC_FUNC(f90_gga_vxc_fxc, F90_GGA_VXC_FXC)
+     (void **p, CC_FORTRAN_INT *np, FLOAT *rho, FLOAT *sigma, 
+      FLOAT *vrho, FLOAT *vsigma,
+      FLOAT *v2rho2, FLOAT *v2rhosigma, FLOAT *v2sigma2)
+{
+  XC(gga)((XC(func_type) *)(*p), *np, rho, sigma, NULL, vrho, vsigma, 
+	  v2rho2, v2rhosigma, v2sigma2, NULL, NULL, NULL, NULL);
+}
+
 void XC_FC_FUNC(f90_gga_fxc, F90_GGA_FXC)
      (void **p, CC_FORTRAN_INT *np, FLOAT *rho, FLOAT *sigma, 
       FLOAT *v2rho2, FLOAT *v2rhosigma, FLOAT *v2sigma2)
@@ -398,6 +418,19 @@ void XC_FC_FUNC(f90_mgga_vxc, F90_MGGA_VXC)
 	   NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
 }
 
+void XC_FC_FUNC(f90_mgga_vxc_fxc, F90_MGGA_VXC_FXC)
+  (void **p, CC_FORTRAN_INT *np, FLOAT *rho, FLOAT *sigma, FLOAT *lapl, FLOAT *tau,
+   FLOAT *vrho, FLOAT *vsigma, FLOAT *vlapl, FLOAT *vtau,
+   FLOAT *v2rho2, FLOAT *v2sigma2, FLOAT *v2lapl2, FLOAT *v2tau2,
+   FLOAT *v2rhosigma, FLOAT *v2rholapl, FLOAT *v2rhotau, 
+   FLOAT *v2sigmalapl, FLOAT *v2sigmatau, FLOAT *v2lapltau)
+{
+  XC(mgga)((XC(func_type) *)(*p), *np, rho, sigma, lapl, tau, 
+	   NULL, vrho, vsigma, vlapl, vtau,
+	   v2rho2, v2sigma2, v2lapl2, v2tau2, v2rhosigma, v2rholapl, v2rhotau, 
+	   v2sigmalapl, v2sigmatau, v2lapltau);
+}
+
 void XC_FC_FUNC(f90_mgga_fxc, F90_MGGA_FXC)
   (void **p, CC_FORTRAN_INT *np, FLOAT *rho, FLOAT *sigma, FLOAT *lapl, FLOAT *tau,
       FLOAT *v2rho2, FLOAT *v2sigma2, FLOAT *v2lapl2, FLOAT *v2tau2,
